                                       ############################################################
                                      ####                                                      ####
                                      ####  LOGIT-TRANSFORMATION:                               ####
                                      ####                                                      ####
                                      ####  Lesser black-backed gull (Larus fuscus) on Horsvr, ####
                                      ####  Northern Norway                                     ####
                                      ####                                                      ####
                                      ####     Brd-Jrgen Brdsen (bjb@nina.no) & Jan Ove      ####
                                      ####     Bustnes, 31.03.2021                              ####
                                      ####                                                      ####
                                       ############################################################


# NOTES: This function transforms probabilities/proportions to logit or log-odds (if anti = F) and
#        vice-versa (if anti = T). 



                                        ############
                                        # FUNCTION #
                                        ############

Logit <- function( x, anti = F,              # transforms proportional/probability to logit or log-odds if 'anti = F'
                  I = 1,                     # 'I' is the asymptote (1 is default; like in e.g. link = logit in 'glm')
                  digits = 10 )              # the precision of the calculated values
  
   { if ( anti == F )                        
           round( log( x / (1 - x) ),
               digits )  else                # 'digits' gives the number of digits to appear

     if ( anti == T )                        # if anti = T; the antilog(it) of 'x', i.e. transforms logit to   
         { x <-  exp ( x )                   # proportional/probability scale 
           round ( I * ( 1 / (1 + (1/x) ) ),
                 digits ) }
   }

# EXAMPLE #
#Logit(-.328, anti = T)                       # the antilog(it) of -0.328 which equals 0.41872
#Logit(.4187, anti = F, digits = 3)           # the logit of 0.4187 which equals -0.328 (with three digits)



