                                       ############################################################
                                      ####                                                      ####
                                      ####  SIMULATIONS - LESLIE MATRIX (AGE-MODEL):            ####
                                      ####                                                      ####
                                      ####  Lesser black-backed gull (Larus fuscus) on Horsvr, ####
                                      ####  Northern Norway                                     ####
                                      ####                                                      ####
                                      ####     Brd-Jrgen Brdsen (bjb@nina.no) & Jan Ove      ####
                                      ####     Bustnes, 22.02.2022                              ####
                                      ####                                                      ####
                                       ############################################################





                                        ##############################################################
                                        # RUNNING THE SIMULATIONS: DIFFERENT ENVIRONMENTAL SCENARIOS #
                                        ##############################################################


for ( p in 1:nGroup )
  {                                                                           # 1) p-loop: START
    for (s in 1:nSim)
      {                                                                       # 2) s-loop: START

        { if (Pred == FALSE)                                                  # 3) Pred-condition: START (FALSE means that environmental conditions are manipulated)
            { if (manip == "increase")                                        # 4) manip-condition: START (increase means that environmental conditions are improved)
                { sim <- MatrixModel( data = idata, dataPop = idataPop,       # running the simulation over 's' different simulations
                    TimeLoop = TimeLoop, MaxMin = EnviData[p],
                    ProbShape = "increase", maxN = maxN,
                    VitalAdult = VitalAdult, VitalOffsp = VitalOffsp)
                }
              else if (manip == "decrease")
                { sim <- MatrixModel( data = idata, dataPop = idataPop,
                    TimeLoop = TimeLoop, MaxMin = EnviData[p],
                    ProbShape = "decrease", maxN = maxN,
                    VitalAdult = VitalAdult, VitalOffsp = VitalOffsp)
                }
            }                                                                 # 4) manip-condition: END
          else if (Pred == TRUE)                                              # 3) Pred-condition: CONTIMUATION (TRUE means that egg predation is manipulated)
            { iidata <- idata                                                 # manipulates initial data and the vital rates so they take into account egg predation
              iidata$Reproduction <- iidata$Reproduction*(1-PredData[p])
              VITALadult <- VitalAdult; VITALoffsp <- VitalOffsp
              VITALadult$recr <- VITALadult$recr*(1-PredData[p])
              { if (manip == "increase")                                      # 4) manip-condition: START
                  { sim <- MatrixModel( data = idata, dataPop = idataPop,
                      TimeLoop = TimeLoop, MaxMin = EnviIndex,
                      ProbShape = "increase", maxN = maxN,
                      VitalAdult = VITALadult, VitalOffsp = VITALoffsp)
                  }
                else if (manip == "decrease")
                  { sim <- MatrixModel( data = idata, dataPop = idataPop,
                      TimeLoop = TimeLoop, MaxMin = EnviIndex,
                      ProbShape = "decrease", maxN = maxN,
                      VitalAdult = VITALadult, VitalOffsp = VITALoffsp)
                 }
              }                                                               # 4) manip-condition: END
            }
        }                                                                     # 3) Pred-condition: END

        TMP <- data.frame(Simulation = s, sim$data)                           # extracts the class specific data from the object 'sim'
        TMP1 <- data.frame(Simulation = s, sim$dataPop)                       # extracts the population specific data from the object 'sim'
        TMP2 <- data.frame(Simulation = s, sim$EnviroData)                    # extracts the climate data from the object 'sim'

        { if (s == 1)                                                         # for the first simulation (i.e., the first trajectory) some objects are created
            { data <- TMP                                                     #   class-specific data
              dataPop <- TMP1                                                 #   population-specific data
              EnviroData <- TMP2                                              #   climate-data
              A <- sim$A }                                                    #   projection matrices for each year (defined by the 'Data.collection' argument in 'MatrixModel.R')
          else                                                                # for the rest of the simulations data are added to the objects created for the first simulation
            { data <- rbind.data.frame(data, TMP)
              dataPop <- rbind.data.frame(dataPop,TMP1)
              EnviroData <- rbind.data.frame(EnviroData,TMP2)
              A <- c(A, sim$A) }
        }
      }                                                                       # 2) s-loop: END


         ### PERTURBATION ANALYSES: ELASTICITY/SENSITIVITY ####

      tmp <- subset(data, Time >= 1)                                          # use a subset of the data excluding the initial year. NB! for the vital rates, we do not exclude
                                                                              #    data according to 'Data.collection' (as they do not have 'burn-in' time similar to the population
                                                                              #    size (years are selected randomly according to the 'YearProb').
      AverData <- as.data.frame(as.table(tapply((tmp$P),                      # calculates the average survival across year for each class
        list(tmp$Class), mean,na.rm = T)))
        names(AverData) <- c("Class", "P")
      AverData$F <- as.data.frame(as.table(tapply(tmp$F,                      # calculates the average reproduction across year for each class
        list(tmp$Class),mean,na.rm = T)))[,2]
      A.mean <- matrix(rep(0,(dim(AverData)[1])^2), nrow = dim(AverData)[1],  # constructing the average matrix
        byrow = TRUE, dimnames = list(c(AverData$Class), c(AverData$Class)))
      A.mean[1,] <- c(AverData$F)                                             # setting up the fecundities ('F') in the top row
        for(i in 2:(dim(A.mean)[1]) )                                         # setting up the survival rates ('P')
          { A.mean[(i),(i-1)] <- (AverData$P[(i-1)]) }
      A.mean[dim(A.mean)[1],dim(A.mean)[1]] <-                                # adds the survival rates for the last age class
        (AverData$P[length(AverData$P)])
      eigA.mean <- eigen.analysis(A.mean)                                     # performs perturbation analyses (i.e., the eigenvalues)
      ElasticityA.mean <- eigA.mean$elasticities                              # extracts elasticise
      SensitivityA.mean <- eigA.mean$sensitivities                            # extracts sensitivities
      ReproValueA.mean <-  eigA.mean$repro.value                              # reproductive values (scaled so 'v[1] = 1')
      StableStageA.mean <-  eigA.mean$stable.stage                            # eigenvalue and -vector analyses of a projection matrix model using matrix algebra
      genTimeA.mean <- generation.time(A.mean)                                # calculates the generation time of a stage-classified matrix (using mean values for 'F' and 'P')


         ### VITAL RATE TEMPORAL VARIABILITY ###

      CoVaData <- as.data.frame(as.table(tapply((tmp$Survival),               # calculates the variance (standard deviation) for survival across years age class
        list(tmp$Class), sd, na.rm = T)))
      names(CoVaData) <- c("Class", "Survival")
      CoVaData$Reproduction <- as.data.frame(as.table(tapply(                 # calculates variance (standard deviation) for fecundity across years age class
        tmp$F, list(tmp$Class),sd, na.rm = T)))[,2]
      A.sd <- matrix(rep(0, (dim(CoVaData)[1])^2), nrow = dim(CoVaData)[1],   # constructing a matrix with its values
        byrow = TRUE, dimnames = list(c(CoVaData$Class), c(CoVaData$Class)))
      Amean <- A.sd
      A.sd[1,] <- c(CoVaData$Reproduction)
      for(i in 2:(dim(A.sd)[1]) )
        { A.sd[(i),(i-1)] <- CoVaData$Survival[(i-1)] }
      A.sd[dim(Amean)[1],dim(Amean)[1]] <-
        CoVaData$Survival[length(CoVaData$Survival)]
      Amean[1,] <- c(AverData$F)
      for(i in 2:(dim(A.mean)[1]) )
        { Amean[(i),(i-1)] <- AverData$P[(i-1)] }
      Amean[dim(Amean)[1],dim(Amean)[1]] <-
        AverData$P[length(CoVaData$Survival)]
      VitaRate.cv <- abs(A.sd/Amean)                                          # calculates the CV for each vital rate
        rm(A.sd, Amean, AverData, CoVaData, tmp)
      VitaRate.cv[is.nan(VitaRate.cv)] <- NA                                  # defines NaN as NA
      ElasticityA.mean[is.na(VitaRate.cv)] <- NA                              # defines zero entries in the transition matrix as NA
      SensitivityA.mean[is.na(VitaRate.cv)] <- NA                             # defines zero entries in the transition matrix as NA


         ### ASSESSSING EXTINCTION PROBABILITIES ###

      n <- data$nObs[data$Time == 0  & data$Simulation == 1]                  # initial population sizes
        names(n) <- as.character(data$Class[data$Time == 0 &                  # naming the vector 'n'
        data$Simulation == 1])
      A.stoch <- stoch.growth.rate(A, maxt = maxt, verbose = F)               # calculates the log stochastic growth rate by Tuljapukar's approximation and by simulation
                                                                              #   'A' and 'prob' are the same as above
                                                                              #   'maxt' is the number of time intervals (default 50000)

      if ( printRawData == T & sum(p==simPrint) == 1)                         # 4) 1st 'printRawData'-condition (these are only calculated when results are stored externally): START


        # NOTE: For a selection of runs, we provide additional details for testing purposes - this is not a part of the final output found in the 'DATABASE' directory

        { A.stoch.proj <- stoch.projection(A, tmax = TimeLoop,                # simulates stochastic growth by projection (see 'ExtinctionSensitivity.R' for details)
           n, nreps = Maxruns, verbose = F)
          A.extin <- stoch.quasi.ext(A, n0 = n, Nx = ExtThres,                # estimate the quasi-extinction probability (see 'ExtinctionSensitivity.R' for details)
           tmax = ExtTime, maxruns = 10, nreps = Maxruns, prob = NULL,
           sumweight = NULL, verbose = F)
        }                                                                     # 4) 1st 'printRawData'-condition: END


         ### COMPILES DATA FROM THE DATA COLLECTION PERIOD ###

      tmp <- subset(data, Time >= round(TimeLoop*Data.collection,0))          # use a subset of the data (consisting of the selected part of time series defined by Data.collection)
      tmp$MaxMin <- sim$MaxMin                                                # extracts the value for 'MaxMin' in the simulation
      tmp$ProbShape <- sim$ProbShape                                          # extracts information of whether we improved ('increase') or worsened ('decrase') the environment
      tmp2 <- subset(dataPop, Time >= round(TimeLoop*Data.collection,0))      # use a subset of the population data (the selected part of time series defined by Data.collection)
      tmp2$MaxMin <- sim$MaxMin
      tmp2$ProbShape <- sim$ProbShape
      tmp6 <- data.frame(N = tmp2$N, id = paste(tmp2$Simulation,tmp2$Time ))  # creates a data.frame consisting of population abundance and an id specific to time and simulation

      tmp$id <-  paste(tmp$Simulation,tmp$Time )                              # creates a unique ID
      tmp <- merge(tmp, tmp6, by.x = "id", by.y = "id")


      { if (p == 1)                                                           # 5) p-condition: START
        {                                                                     # in the first simulation: i.e., when p = 1, the data seta is created
          SimuData <- as.data.frame(as.table(tapply(tmp$nObs,                 # extracts median number of individuals per age-class
            list(tmp$MaxMin, tmp$Class), median)))
          names(SimuData) <- c("MaxMin", "Class", "nObs.median")              # re-names variables
          { if (Pred == FALSE)                                                # 6) Pred-condition: START
              { SimuData$MaxMin <- as.numeric(sim$MaxMin) }                   # 'MaxMin' means the value for EGI/EHI if environmental conditions are manipulated
            else if (Pred == TRUE)
              { SimuData$MaxMin <- PredData[p] }                              # 'MaxMin' means the proportion of eggs lost to predation if predation is manipulated
          }                                                                   # 6) Pred-condition: END
          SimuData$nObs.quant2 <- as.data.frame(as.table(tapply(              # extracts 25th percentile for body mass per age-class
            tmp$nObs, list(tmp$Class), quant2)))[,2]
          SimuData$nObs.quant4 <- as.data.frame(as.table(tapply(              # extracts 25th percentile for body mass per age-class
            tmp$nObs, list(tmp$Class), quant4)))[,2]
          SimuData$Surv.median <- as.data.frame(as.table(tapply(              # extracts median survival per age-class
            tmp$Survival, list(tmp$Class), median)))[,2]
          SimuData$Surv.quant2 <- as.data.frame(as.table(tapply(              # extracts 25th percentile for survival per age-class
            tmp$Survival, list(tmp$Class), quant2)))[,2]
          SimuData$Surv.quant4 <- as.data.frame(as.table(tapply(              # extracts 75th percentile for survival per age-class
            tmp$Survival, list(tmp$Class), quant4)))[,2]
          SimuData$Repr.median <- as.data.frame(as.table(tapply(              # extracts median survival per age-class
            tmp$F, list(tmp$Class), median)))[,2]
          SimuData$Repr.quant2 <- as.data.frame(as.table(tapply(              # extracts 25th percentile for survival per age-class
            tmp$F, list(tmp$Class), quant2)))[,2]
          SimuData$Repr.quant4 <- as.data.frame(as.table(tapply(              # extracts 75th percentile for survival per age-class
            tmp$F, list(tmp$Class), quant4)))[,2]
          SimuData$nSim <- s                                                  # number of simulations
          SimuData$nYear <- dim(subset(tmp, Simulation == 1 & Class == 1))[1] # number of years (in the first simulation)

          SimuDataPop <- as.data.frame(as.table(tapply(tmp2$N,                # extracts median abundance
            list( tmp2$MaxMin), median)))
          names(SimuDataPop) <- c("MaxMin", "N.median")                       # re-names variables
          SimuDataPop$MaxMin <- SimuData$MaxMin[1]                            # same as in 'SimuData' above
          SimuDataPop$N.quant2 <- quant2(tmp2$N)                              # extracts 25th percentile for abundance
          SimuDataPop$N.quant4 <- quant4(tmp2$N)                              # extracts 75th percentile for abundance
          SimuDataPop$N2.median <- median(tmp2$N2, na.rm = T)                 # extracts median abundance in the last age-class
          SimuDataPop$N2.quant2 <- quant2(tmp2$N2)                            # extracts 25th percentile for abundance in the last age-class
          SimuDataPop$N2.quant4 <- quant4(tmp2$N2)                            # extracts 75th percentile for abundance in the last age-class
          SimuDataPop$Lambda.Tuljapurk <- A.stoch$approx                      # extracts stochastic (log-) lambda using sing Tuljapukar's second order approximation from A.stoch
          SimuDataPop$Lambda.sim <- A.stoch$sim                               # extracts stochastic (log-) lambda based on the average over successive growth rates from A.stoch
          SimuDataPop$Lambda.simLCL <- A.stoch$sim.CI[1]                      # extracts the lower confidence limit of the simulated stochastic (log-) lambda from A.stoch
          SimuDataPop$Lambda.simUCL <- A.stoch$sim.CI[2]                      # extracts the upper confidence limit of the simulated stochastic (log-) lambda from A.stoch
          SimuDataPop$Lambda.simUCL <- A.stoch$sim.CI[2]                      # extracts the upper confidence limit of the simulated stochastic (log-) lambda from A.stoch
          SimuDataPop$Lambda.sim_maxt <- maxt                                 # the number of time intervals to simulate the log stochastic growth rate (see 'A.stoch' above)
          SimuDataPop$Lambda.median <- median(tmp2$Lambda, na.rm = T)         # extracts median lambda (from the population projection)
          SimuDataPop$Lambda.quant2 <- quant2(tmp2$Lambda)                    # extracts 25th percentile for lambda (from the population projection)
          SimuDataPop$Lambda.quant4 <- quant4(tmp2$Lambda)                    # extracts 75th percentile for lambda (from the population projection)
          SimuDataPop$Lambda2.median <- median(tmp2$Lambda2, na.rm = T)       # extracts median lambda (i.e., the growth based on data for the last age-class only)
          SimuDataPop$Lambda2.quant2 <- quant2(tmp2$Lambda2)                  # extracts 25th percentile for lambda (i.e., the growth based on data for the last age-class only)
          SimuDataPop$Lambda2.quant4 <- quant4(tmp2$Lambda2)                  # extracts 75th percentile for lambda (i.e., the growth based on data for the last age-class only)
          SimuDataPop$nSim <- s                                               # extracts the number simulations used in this assessment
          SimuDataPop$nYear <- dim(subset(tmp2, Simulation == 1))[1]          # number of years (in the first simulation)
          SimuDataPop$genTimeA.mean <- genTimeA.mean
        }
          else                                                                # in the remaining simulations: i.e., when 'i' != 1, the same information is added to 'SimuData' & 'SimuDataPop'
        {
          TMP <- as.data.frame(as.table(tapply(tmp$nObs,
            list(tmp$MaxMin, tmp$Class), median)))
          names(TMP) <- c("MaxMin", "Class", "nObs.median")
          { if (Pred == FALSE)                                                # 6) Pred-condition: START
              { TMP$MaxMin <- as.numeric(sim$MaxMin) }
            else if (Pred == TRUE)
              { TMP$MaxMin <- PredData[p] }
          }                                                                   # 6) Pred-condition: END
          TMP$nObs.quant2 <- as.data.frame(as.table(tapply(
            tmp$nObs, list(tmp$Class), quant2)))[,2]
          TMP$nObs.quant4 <- as.data.frame(as.table(tapply(
            tmp$nObs, list(tmp$Class), quant4)))[,2]
          TMP$Surv.median <- as.data.frame(as.table(tapply(
            tmp$Survival, list(tmp$Class), median)))[,2]
          TMP$Surv.quant2 <- as.data.frame(as.table(tapply(
            tmp$Survival, list(tmp$Class), quant2)))[,2]
          TMP$Surv.quant4 <- as.data.frame(as.table(tapply(
            tmp$Survival, list(tmp$Class), quant4)))[,2]
          TMP$Repr.median <- as.data.frame(as.table(tapply(
            tmp$F, list(tmp$Class), median)))[,2]
          TMP$Repr.quant2 <- as.data.frame(as.table(tapply(
            tmp$F, list(tmp$Class), quant2)))[,2]
          TMP$Repr.quant4 <- as.data.frame(as.table(tapply(
            tmp$F, list(tmp$Class), quant4)))[,2]
          TMP$nSim <- s
          TMP$nYear <- dim(subset(tmp, Simulation == 1 & Class == 1))[1]
          TMP2 <- as.data.frame(as.table(tapply(tmp2$N,
            list( tmp2$MaxMin), median)))
          names(TMP2) <- c("MaxMin", "N.median")
          TMP2$MaxMin <- TMP$MaxMin[1]
          TMP2$N.quant2 <- quant2(tmp2$N)
          TMP2$N.quant4 <- quant4(tmp2$N)
          TMP2$N2.median <- median(tmp2$N2, na.rm = T)
          TMP2$N2.quant2 <- quant2(tmp2$N2)
          TMP2$N2.quant4 <- quant4(tmp2$N2)
          TMP2$Lambda.Tuljapurk <- A.stoch$approx
          TMP2$Lambda.sim <- A.stoch$sim
          TMP2$Lambda.simLCL <- A.stoch$sim.CI[1]
          TMP2$Lambda.simUCL <- A.stoch$sim.CI[2]
          TMP2$Lambda.simUCL <- A.stoch$sim.CI[2]
          TMP2$Lambda.sim_maxt <- maxt
          TMP2$Lambda.median <- median(tmp2$Lambda, na.rm = T)
          TMP2$Lambda.quant2 <- quant2(tmp2$Lambda)
          TMP2$Lambda.quant4 <- quant4(tmp2$Lambda)
          TMP2$Lambda2.median <- median(tmp2$Lambda2, na.rm = T)
          TMP2$Lambda2.quant2 <- quant2(tmp2$Lambda2)
          TMP2$Lambda2.quant4 <- quant4(tmp2$Lambda2)
          TMP2$nSim <- s
          TMP2$nYear <- dim(subset(tmp2, Simulation == 1))[1]
          TMP2$genTimeA.mean <- genTimeA.mean

          SimuData <- rbind.data.frame(SimuData, TMP)
          SimuDataPop <- rbind.data.frame(SimuDataPop, TMP2)
        }
      }                                                                       # 5) p-condition: END


         ### SAVING RESULTS FOR EACH INDIVIDUAL SIMULATION ###

      if ( printRawData == T & sum(p==simPrint) == 1 )
        {                                                                     # 6) 2nd 'printRawData'-condition: START

          # NOTE: Some of this output (sim) prints important output for ONE (single) run: i.e., trajectory in the 's-loop' and the 'p-loop' (the last one
          #       in each). The remaining consist of output from all runs (i.e., across all simulations in the 'p-loop').
          { if (Pred == FALSE)                                                # 6) Pred-condition: START
              { TMP <- as.numeric(sim$MaxMin) }                               # 'MaxMin' means the value for EGI/EHI if environmental conditions are manipulated
            else if (Pred == TRUE)
              { TMP <- PredData[p] }                                          # 'MaxMin' means the proportion of eggs lost to predation if predation is manipulated
          }                                                                   # 6) Pred-condition: END
          tmpDIR <- paste( "Manip(",as.character(sim$ProbShape),              # file name when storing the workspace
            ")_MaxMin(",round(TMP,4),")_T(", TimeLoop,")", sep="" )
          dir.create(paste(getwd(),"/",tmpDIR, sep =""), showWarnings = F)    # creates a new directory
          setwd(paste(getwd(),"/",tmpDIR, sep =""))                           # defines this new directory as the current working directory (to store output)
          save( A, A.mean, sim, ElasticityA.mean, SensitivityA.mean, A.extin, # stores the output as an R workspace (in the directory 'AgeMod--MatrixSimulation')
            ReproValueA.mean, StableStageA.mean, VitaRate.cv, A.stoch, Pred,
            file = "Rawdata.RData" )
          source(paste(wd, "/MatrixSimulationAnalyzing.R", sep = ""))         # creates a set of different plots
          graphics.off()
          setwd(Wd)
        }                                                                     # 6) 2nd 'printRawData'-condition: END

  }                                                                           # 1) p-loop: END


      ### SAVING RESULTS FOR ALL SIMULATIONS ###

save(SimuData, SimuDataPop, file = "DATABASE/SimuData.RData")                 # stores the compiled data in the 'DATABASE' directory within the current working directory
wb <- createWorkbook()                                                        # creates the workbook or .xlsx-file
addWorksheet(  wb, sheetName = "SimuData")                                    # creates the sheet
freezePane(    wb, sheet = "SimuData", firstRow = TRUE,
  firstCol = TRUE)                                                            # freeze first row and column
writeDataTable(wb, sheet = "SimuData", x = SimuData)                          # adds data to the sheet
addWorksheet(  wb, sheetName = "SimuDataPop")
freezePane(    wb, sheet = "SimuDataPop", firstRow = TRUE,
  firstCol = TRUE)
writeDataTable(wb, sheet = "SimuDataPop",
  x = SimuDataPop)
saveWorkbook(wb, "DATABASE/SimuData.xlsx", overwrite = TRUE);rm(wb)           # saves the file





                                        #######################
                                        # PLOTTING OF RESULTS #
                                        #######################

source(paste(wd, "/MatrixSimulationPlottingResults.R",sep = ""))              # plotting and analysing results (based on the script 'MatrixSimulationPlottingResults.R')
