                                       ############################################################
                                      ####                                                      ####
                                      ####  DETAILED OUTPUT FOR A SELECTION OF SIMULATIONS:     ####
                                      ####                                                      ####
                                      ####  Lesser black-backed gull (Larus fuscus) on Horsvr, ####
                                      ####  Northern Norway                                     ####
                                      ####                                                      ####
                                      ####     Brd-Jrgen Brdsen (bjb@nina.no) & Jan Ove      ####
                                      ####     Bustnes, 22.02.2022                              ####
                                      ####                                                      ####
                                       ############################################################


# NOTE: This script adds output to one out of a default of five different directories for each manipulation (used for testing purposes only).






                                        #########
                                        # INPUT #
                                        #########


lwd <- 2
cex.axis <- 1.8                                                               # size of legends for the axes
cex.point <- 1.8                                                              # size of the points
back.col <- c("black")                                                        # colours to be used for the background data
plot.label <- Label
pch <- c(16,17,18)                                                            # pch used for plotting age-classes other than the youngest one






                                        ##########################
                                        # ANALYSING THE MATRICES #
                                        ##########################


   ### POPULATION ABUNDANCE (TRAJECTORIES) ###

dev.new(width=14/2.54, height=14/2.54);par(bty = "l", cex.axis = cex.axis,    # setting up the plot
    mar = c(4, 4, 2.5, 0.35), oma = c(1, 1.5, 1, 0.5),                        # mar is figure margins; oma is outer margins (both: 'c(bottom, left, top, right)')
    layout( rbind( c(1,1) )))
plot(N~Time, data = dataPop, type = "n", xlab = "",                           # plots population time series
  ylab ="", lwd = lwd[1])
for(i in 1:length(levels(as.factor(data$Simulation))))                        # one grey line for each population trajectory
  { lines(dataPop$N[dataPop$Simulation ==
     levels(as.factor(dataPop$Simulation))[i]] ~
     dataPop$Time[dataPop$Simulation ==
     levels(as.factor(dataPop$Simulation))[i]],
     col = terrain.colors(length(levels(as.factor(data$Simulation))))[i],
     lty = 4, lwd = .8)
  }
mtext(side = 2, expression("Population abundance ("*italic(N)*")"),           # adds a label to the Y-axis
  line = -.7, cex = cex.axis, outer = T)
mtext(side = 1, "Time (year)", line = -0.2, cex = cex.axis, outer = T)        # adds a label to the X-axis
dev.copy(tiff, filename = "AbundTrajactories.tiff", units="cm", width=14,     # saves the plot externally as a .tiff-file
  height=14, res=200, compression = c("lzw"));dev.off()


   ### POPULATION ABUNDANCE (QUARTILES) ###

dev.new(width=14/2.54, height=14/2.54);par(bty = "l", cex.axis = cex.axis,
    mar = c(4, 4, 2.5, 0.35), oma = c(1, 1.5, 1, 0.5),
    layout( rbind( c(1,1) )))
plot(N~Time, data = dataPop, type = "n", log = "y", xlab = "",
  ylab ="", lwd = lwd[1])
for(i in 1:length(levels(as.factor(data$Simulation))))
  { lines(dataPop$N[dataPop$Simulation ==
     levels(as.factor(dataPop$Simulation))[i]] ~
     dataPop$Time[dataPop$Simulation ==
     levels(as.factor(dataPop$Simulation))[i]],
     col = "grey", lty = 4, lwd = .8)
  }
median <- tapply(dataPop$N, dataPop$Time, median, na.rm = T)                  # estimates the median value per year (across simulations)
Quant2 <- tapply(dataPop$N, dataPop$Time, quant2)                             # estimates the 25th quantile per year (across simulations)
Quant4 <- tapply(dataPop$N, dataPop$Time, quant4)                             # estimates the 75th quantile per year (across simulations)
time   <- tapply(dataPop$Time, dataPop$Time, mean)                            # extracts one value for time each year
lines(median~time,  col = "red", lwd = lwd[1])                                # adds the median to the plot
lines(Quant2~time,  col = "blue", lwd = lwd[1]*.5, lty = 2)                   # adds the 25th quantile to the plot
lines(Quant4~time,  col = "blue", lwd = lwd[1]*.5, lty = 2)                   # adds the 75th quantile to the plot
rm(median, time, Quant2, Quant4)
mtext(side = 2, expression("Population abundance ("*italic(N)*")"),
  line = -.7, cex = cex.axis, outer = T)
mtext(side = 1, "Time (year)", line = -0.2, cex = cex.axis, outer = T)
dev.copy(tiff, filename = "AbundTrajQuartiles.tiff", units="cm", width=14,
  height=14, res=200, compression = c("lzw"));dev.off()


   ### POPULATION ABUNDANCE FOR AGE-CLASS 2 (TRAJECTORIES) ###

dev.new(width=14/2.54, height=14/2.54);par(bty = "l", cex.axis = cex.axis,
    mar = c(4, 4, 2.5, 0.35), oma = c(1, 1.5, 1, 0.5),
    layout( rbind( c(1,1) )))
plot(N2~Time, data = dataPop, type = "n", xlab = "",
  ylab ="", lwd = lwd[1])
for(i in 1:length(levels(as.factor(data$Simulation))))
  { lines(dataPop$N2[dataPop$Simulation ==
     levels(as.factor(dataPop$Simulation))[i]] ~
     dataPop$Time[dataPop$Simulation ==
     levels(as.factor(dataPop$Simulation))[i]],
     col = terrain.colors(length(levels(as.factor(data$Simulation))))[i],
     lty = 4, lwd = .8)
  }
mtext(side = 2, expression("Population abundance ("*italic(N["age = "*4] )*
  ")"), line = -.7, cex = cex.axis, outer = T)
mtext(side = 1, "Time (year)", line = -0.2, cex = cex.axis, outer = T)
dev.copy(tiff, filename = "AbundTrajactories(ageCl4).tiff", units="cm",
  width=14, height=14, res=200, compression = c("lzw"));dev.off()


   ### POPULATION ABUNDANCE FOR AGE-CLASS 2 (QUARTILES) ###

dev.new(width=14/2.54, height=14/2.54);par(bty = "l", cex.axis = cex.axis,
    mar = c(4, 4, 2.5, 0.35), oma = c(1, 1.5, 1, 0.5),
    layout( rbind( c(1,1) )))
plot(N2~Time, data = dataPop, type = "n", log = "y", xlab = "",
  ylab ="", lwd = lwd[1])
for(i in 1:length(levels(as.factor(data$Simulation))))
  { lines(dataPop$N2[dataPop$Simulation ==
     levels(as.factor(dataPop$Simulation))[i]] ~
     dataPop$Time[dataPop$Simulation ==
     levels(as.factor(dataPop$Simulation))[i]],
     col = "grey", lty = 4, lwd = .8)
  }
median <- tapply(dataPop$N2, dataPop$Time, median, na.rm = T)
Quant2 <- tapply(dataPop$N2, dataPop$Time, quant2)
Quant4 <- tapply(dataPop$N2, dataPop$Time, quant4)
time   <- tapply(dataPop$Time, dataPop$Time, mean)
lines(median~time,  col = "red", lwd = lwd[1])
lines(Quant2~time,  col = "blue", lwd = lwd[1]*.5, lty = 2)
lines(Quant4~time,  col = "blue", lwd = lwd[1]*.5, lty = 2)
rm(median, time, Quant2, Quant4)
mtext(side = 2, expression("Population abundance ("*italic(N["age = "*4] )*
  ")"), line = -.7, cex = cex.axis, outer = T)
mtext(side = 1, "Time (year)", line = -0.2, cex = cex.axis, outer = T)
dev.copy(tiff, filename = "AbundTrajQuartiles(ageCl2).tiff", units="cm",
  width=14, height=14, res=200, compression = c("lzw"));dev.off()


   ### CALCULATING THE AVERAGE MATRIX & ELASTICITIES ####

dev.new(width=14/2.54, height=25/2.54);par(bty = "l", cex.axis = cex.axis,
    mar = c(4, 4, 2.5, 0.35), oma = c(1, 1.5, 1, 0.5),
    layout( rbind( c(1), c(2) )))
image2(ifelse(ElasticityA.mean == 0, NA, ElasticityA.mean),                   # plots the elasticities
  mar=c(0.5,1,4,0) , box.offset=.1 )
mtext(side = 3, expression(lambda~"elasticities (average matrix)"),
  cex = cex.axis, line = 1)
image2(ifelse(is.na(VitaRate.cv) == T, NA, VitaRate.cv),                      # plots the CV for each vital rate
  mar=c(0.5,1,4,0) , box.offset=.1, )
mtext(side = 3, "Vital rate CV", cex = cex.axis, line = 1)
dev.copy(tiff, filename = "ElastVitalCV.tiff", units="cm",
  width=14, height=25, res=200, compression = c("lzw"));dev.off()


   ### CALCULATING THE AVERAGE MATRIX & SENSITIVITIES ####

dev.new(width=14/2.54, height=25/2.54);par(bty = "l", cex.axis = cex.axis,
    mar = c(4, 4, 2.5, 0.35), oma = c(1, 1.5, 1, 0.5),
    layout( rbind( c(1), c(2) )))
image2(ifelse(SensitivityA.mean == 0, NA, SensitivityA.mean),                 # plots the sensitivities
  mar=c(0.5,1,4,0) , box.offset=.1 )
mtext(side = 3, expression(lambda~"sensitivity (average matrix)"),
  cex = cex.axis, line = 1)
image2(ifelse(is.na(VitaRate.cv) == T, NA, VitaRate.cv),
  mar=c(0.5,1,4,0) , box.offset=.1, )
mtext(side = 3, "Vital rate CV", cex = cex.axis, line = 1)
dev.copy(tiff, filename = "SensiVitalCV.tiff", units="cm",
  width=14, height=25, res=200, compression = c("lzw"));dev.off()


   ### STABLE STAGE DISTRIBUTION (AVERAGE MATRIX) ####

dev.new(width=14/2.54, height=14/2.54);par(bty = "l", cex.axis = cex.axis,
    mar = c(4, 4, 2.5, 0.35), oma = c(1, 1.5, 1, 0.5),
    layout( rbind( c(1,1) )))
names(StableStageA.mean)<-levels(as.factor(data$Class))
barplot(StableStageA.mean, ylab = "", xlab = "", col = "black")               # plots the stable stage-structure (based on the average matrix)
mtext(side = 2, expression("Population in stable class (prop.)"),
  line = -.7, cex = cex.axis, outer = T)
mtext(side = 1, "Age class (year)", line = -0.3, cex = cex.axis, outer = T)
dev.copy(tiff, filename = "StableStage.tiff", units="cm",
  width=14, height=14, res=200, compression = c("lzw"));dev.off()


   ### QUASI-EXTINCTION ###

dev.new(width=14/2.54, height=14/2.54);par(bty = "l", cex.axis = cex.axis,
    mar = c(4, 4, 2.5, 0.35), oma = c(1, 1.5, 1, 0.5),
    layout( rbind( c(1,1) )))
matplot(A.extin, ylab = "", xlab = "", type = "l",
    col = rainbow(dim(A.extin)[2]))
mtext(side = 2, expression(italic("Prob.(")*"quasi-extinction)"),             # see 'ExtinctionSensitivity.R' for details on how quasi-extinction was estimated and plotted
  line = -.7, cex = cex.axis, outer = T)
mtext(side = 1, "Time (year)", line = -0.3, cex = cex.axis, outer = T)
dev.copy(tiff, filename = "QuasiExtin.tiff", units="cm",
  width=14, height=14, res=200, compression = c("lzw"));dev.off()
