                                       ############################################################
                                      ####                                                      ####
                                      ####  DETAILED OUTPUT ACROSS ALL SIMULATIONS:             ####
                                      ####                                                      ####
                                      ####  Lesser black-backed gull (Larus fuscus) on Horsvr, ####
                                      ####  Northern Norway                                     ####
                                      ####                                                      ####
                                      ####     Brd-Jrgen Brdsen (bjb@nina.no) & Jan Ove      ####
                                      ####     Bustnes, 22.02.2022                              ####
                                      ####                                                      ####
                                       ############################################################






                                        #########
                                        # INPUT #
                                        #########


   ### DEFINING OPTIONS USED IN THE GENERELIZED ADDITIVE MODEL (GAM) BELOW ###

bs <- c( "cr" )                                                               # cubic regression spline as the basis for the smooth term in the GAM (see Wood 2006:226)
gamma <- 1.4                                                                  # each effective degrees of freedom (edf) will count 1.4 in the GCV score to avid overfitting (Wood 2007:256)


col <-  rainbow(max(max(as.numeric(SimuData$Class))))                         # colours to be used for the different classes in the plot
lty <- 1:max(max(as.numeric(SimuData$Class)))                                 # line types to be used for the different classes in the plot
lwd <- rep(2, max(max(as.numeric(SimuData$Class))))                           # line width to be used for the different classes in the plot
cex.axis <- 1.8                                                               # size of legends for the axes
cex.point <- 1.8                                                              # size of the points
back.col <- c("black")                                                        # colours to be used for the background data
plot.label <- Label
pch <- c(8,17,18, 16)                                                         # pch used for plotting age-classes other than the youngest one

{ if (Pred ==FALSE)                                                           # defines whether manipulation is predation ('TRUE') or environment ('FALSE'): 'MaxMin' in the output file means
    { if (plotLabel == TRUE)                                                  #   the proportion of eggs lost to predation ('TRUE') or the value for the Environmental Goodness Index (EGI; if
        { if (manip == "increase")                                            #   'manip' is 'decrease') or Environmental Goodness Index (EGI; if 'manip' is 'increase'; see 'VitalRates.R' for details)
            { Xlab <- expression("Environmental Goodness Index") }            # labels the X-axis for all plots below (English)
          else
            { Xlab <- expression("Environmental Harshness Index") }           # labels the X-axis for all plots below (English)
        }
      else
        { if (manip == "increase")
            { Xlab <- expression("Miljmessig forbedring") }                  # labels the X-axis for all plots below (Norwegian)
          else
            { Xlab <- expression("Miljmessig forvrring") }                  # labels the X-axis for all plots below (Norwegian)
        }
    }
  else
    { if (plotLabel == TRUE)
        { Xlab <- expression("Egg predation") }                               # labels the X-axis for all plots below (English)
      else
        {  Xlab <- expression("Eggpredasjon") }                               # labels the X-axis for all plots below (Norwegian)
    }
}






                                        ####################
                                        # PLOTTING RESULTS #
                                        ####################


   ### TOTAL POPULATION ABUNDANCE ###

dev.new(width=14/2.54, height=14/2.54);par(bty = "l", cex.axis = cex.axis,    # setting up the plot
    mar = c(4, 4, 2.5, 0.35), oma = c(1, 1.5, 1, 0.5),                        # 'mar' is figure margins; 'oma' is outer margins (both: 'c(bottom, left, top, right)')
    layout( rbind( c(1,1) )))

tmp <- subset(SimuDataPop, N.median >= 1)
{ if (dim(tmp)[1] > 1)
    { mod <- gam(log(N.median) ~ s(MaxMin, bs = bs, k = k),                   # fitting a GAM to the data log-transforming the response (used for plotting purposes)
        family = gaussian(link = "identity"),
        na.action = na.omit, data = tmp)
      newdata <- data.frame(MaxMin = seq(min(tmp$MaxMin),                     # creates a data frame used for making predictions
        max(tmp$MaxMin), length.out = 100 ) )
     newdata$fit <- ( predict(mod, newdata))                                  # extracts the predictions
     newdata$se1 <- ( predict(mod, newdata) +                                 # extracts the predictions + 1 SE
       predict(mod, newdata, se.fit = T)$se.fit )
     newdata$se2 <- ( predict(mod, newdata)  -                                # extracts the predictions - 1 SE
      predict(mod, newdata, se.fit = T)$se.fit )
    newdata[,2:4] <- exp(newdata[,2:4])                                       # transforms the predictions back to normal scale
    plot(SimuDataPop$N.median ~ SimuDataPop$MaxMin,                           # plots the data
      col = back.col, cex = cex.point,
      las = 0, ylim = c( min(c(SimuDataPop$N.quant2, newdata$se2),na.rm = T),
      max(c(SimuDataPop$N.quant4,newdata$se1), na.rm = T)),xlab = "",ylab = "")
    lines(newdata$MaxMin, newdata$fit, lwd = lwd )                            # plotting the predictions
    lines(newdata$MaxMin, newdata$se1, lty = 2, lwd = lwd*.75)                # plotting the predictions - 1 SE
    lines(newdata$MaxMin, newdata$se2, lty = 2, lwd = lwd*.75)                # plotting the predictions + 1 SE
    }
  else
    {
    plot(SimuDataPop$N.median ~ SimuDataPop$MaxMin,                           # plots the data
      col = back.col, cex = cex.point,
      las = 0, xlab = "", ylab = "")
    }
}
mtext(side = 3, plot.label, cex = cex.axis, line = 2)
for ( j in 1:dim(SimuDataPop)[1] )                                            # adds bars (25th and 75th quartiles)
   lines( rep (SimuDataPop$MaxMin[j], 2),
      c(SimuDataPop$N.quant2[j],SimuDataPop$N.quant4[j]),
      col = back.col )
{ if (plotLabel == TRUE)                                                      # if 'plotLabel' is 'TRUE', GAM statistics are plotted AND legends are provided in English
  { mtext(side = 2, expression("Abundance ["*log[e]*"("*                      # adds a label to the Y-axis
      italic(N)*")]"), line = -.7, cex = cex.axis, outer = T)
    mtext(side = 1, Xlab, line = 0.1, cex = cex.axis, outer = T)              # adds a label to the X-axis
    { if (dim(tmp)[1] > 1)
        {  if (formatC(summary(mod)$s.table[4],format = "f",digits = 2) !=    # labels the plot according to the GAM results
               "0.00")
             { mtext( side = 3, adj = .5, cex = cex.axis*.8, line = 0.1,      # adds the estimated degrees of freedom (edf), the P-value and the adjusted R-square to the plot
                as.expression( substitute( edf[GAM] == Value  * ", " ~
                italic(P[GAM])*"-value" == Value1 * ", " ~ italic(R[adj])^2 == Value2,
                list( edf = "edf", GAM = "", Value = formatC(summary(mod)$edf,
                format = "f", digits = 3), Value1 = formatC(
                summary(mod)$s.table[4], format = "f", digits = 2),
                Value2 = formatC(summary(mod)$r.sq,format = "f", digits = 2) ) ) ) )
             }
           else
             { mtext( side = 3, adj = .5, cex = cex.axis*.8, line = 0.1,
                as.expression( substitute( edf[GAM] == Value  * ", " ~
                italic(P[GAM])*"-value" < Value1 * ", " ~ italic(R[adj])^2 == Value2,
                list( edf = "edf", GAM = "", Value = formatC(summary(mod)$edf,
                format = "f", digits = 2), Value1 = "0.01", Value2 =
                formatC(summary(mod)$r.sq,format = "f", digits = 2) ) ) ) )
             }
         }
    }
  }
  else                                                                        # if 'plotLabel' is not TRUE, GAM statistics are not plotted AND legends are provided in Norwegian
  { mtext(side = 2, expression("Totalt antall fugl ("*italic(N)*")"),         # adds a label to the Y-axis
      line = -.7, cex = cex.axis, outer = T)
    mtext(side = 1, Xlab, line = 0.1, cex = cex.axis, outer = T)              # adds a label to the X-axis
  }
}
dev.copy(tiff, filename = "DATABASE/N(log).tiff", units="cm", width=14,       # saves the plot externally as a .tiff-file
  height=14, res=600, compression = c("lzw"));dev.off()


   ### POPULATION ABUNDANCE (AGE-CLASS 4 ONLY) ###

dev.new(width=14/2.54, height=14/2.54);par(bty = "l", cex.axis = cex.axis,
    mar = c(4, 4, 2.5, 0.35), oma = c(1, 1.5, 1, 0.5),
    layout( rbind( c(1,1) )))

tmp <- subset(SimuDataPop, N2.median >= 1)
{ if (dim(tmp)[1] > 15)
    { mod <- gam(log(N2.median) ~ s(MaxMin, bs = bs, k = k),
        family = gaussian(link = "identity"),
        na.action = na.omit, data = tmp)
      newdata <- data.frame(MaxMin = seq(min(tmp$MaxMin),
        max(tmp$MaxMin), length.out = 100 ) )
     newdata$fit <- ( predict(mod, newdata))
     newdata$se1 <- ( predict(mod, newdata) +
       predict(mod, newdata, se.fit = T)$se.fit )
     newdata$se2 <- ( predict(mod, newdata)  -
      predict(mod, newdata, se.fit = T)$se.fit )
    newdata[,2:4] <- exp(newdata[,2:4])
    plot(SimuDataPop$N2.median ~ SimuDataPop$MaxMin,
      col = back.col, cex = cex.point,
      las = 0, ylim = c( min(c(SimuDataPop$N2.quant2, newdata$se2),na.rm = T),
      max(c(SimuDataPop$N2.quant4,newdata$se1), na.rm = T)),xlab = "",ylab = "")
    lines(newdata$MaxMin, newdata$fit, lwd = lwd )
    lines(newdata$MaxMin, newdata$se1, lty = 2, lwd = lwd*.75)
    lines(newdata$MaxMin, newdata$se2, lty = 2, lwd = lwd*.75)
    }
  else
    {
    plot(SimuDataPop$N2.median ~ SimuDataPop$MaxMin,
      col = back.col, cex = cex.point,
      las = 0, xlab = "", ylab = "")
    }
}
mtext(side = 3, plot.label, cex = cex.axis, line = 2)
for ( j in 1:dim(SimuDataPop)[1] )
   lines( rep (SimuDataPop$MaxMin[j], 2),
      c(SimuDataPop$N2.quant2[j],SimuDataPop$N2.quant4[j]),
      col = back.col )
{ if (plotLabel == TRUE)
  { mtext(side = 2, expression("Abundance ["*log[e]*"("*
      italic(N["age=4"])*")]"), line = -.7, cex = cex.axis, outer = T)
    mtext(side = 1, Xlab, line = 0.1, cex = cex.axis, outer = T)
    { if (dim(tmp)[1] > 1)
        {  if (formatC(summary(mod)$s.table[4],format = "f",digits = 2) !=
               "0.00")
             { mtext( side = 3, adj = .5, cex = cex.axis*.8, line = 0.1,
                as.expression( substitute( edf[GAM] == Value  * ", " ~
                italic(P[GAM])*"-value" == Value1 * ", " ~ italic(R[adj])^2 == Value2,
                list( edf = "edf", GAM = "", Value = formatC(summary(mod)$edf,
                format = "f", digits = 3), Value1 = formatC(
                summary(mod)$s.table[4], format = "f", digits = 2),
                Value2 = formatC(summary(mod)$r.sq,format = "f", digits = 2) ) ) ) )
             }
           else
             { mtext( side = 3, adj = .5, cex = cex.axis*.8, line = 0.1,
                as.expression( substitute( edf[GAM] == Value  * ", " ~
                italic(P[GAM])*"-value" < Value1 * ", " ~ italic(R[adj])^2 == Value2,
                list( edf = "edf", GAM = "", Value = formatC(summary(mod)$edf,
                format = "f", digits = 2), Value1 = "0.01", Value2 =
                formatC(summary(mod)$r.sq,format = "f", digits = 2) ) ) ) )
             }
         }
    }
  }
  else
  { mtext(side = 2, expression("Antall fugl ("*italic(N["alder=4"])*")"),
      line = -.7, cex = cex.axis, outer = T)
    mtext(side = 1, Xlab, line = 0.1, cex = cex.axis, outer = T)
  }
}
dev.copy(tiff, filename = "DATABASE/N2(log).tiff", units="cm", width=14,
  height=14, res=600, compression = c("lzw"));dev.off()


   ### REPRODUCTION ###

dev.new(width=14/2.54, height=14/2.54);par(bty = "l", cex.axis = cex.axis,
    mar = c(4, 4, 2.5, 0.35), oma = c(1, 1.8, 1, 0.5),
    layout( rbind( c(1,1) )))
tmp2 <- subset(SimuData, Class == "4")
mod <- gam((Repr.median) ~ s(MaxMin, bs = bs, k = k),                         # this response is not log-transformed
   family = gaussian(link = "identity"),
   na.action = na.omit, data = tmp2)
newdata <- data.frame(MaxMin = seq(min(tmp2$MaxMin),
   max(tmp2$MaxMin), length.out = 100 ) )
newdata$fit <- ( predict(mod, newdata))
newdata$se1 <- ( predict(mod, newdata) +
   predict(mod, newdata, se.fit = T)$se.fit )
newdata$se2 <- ( predict(mod, newdata)  -
   predict(mod, newdata, se.fit = T)$se.fit )
plot(tmp2$Repr.median ~ tmp2$MaxMin,
   cex = cex.point, las = 1,
   ylim = c( min(c(tmp2$Repr.quant2, newdata$se2),
     na.rm = T), max(c(tmp2$Repr.quant4, newdata$se2), na.rm = T)),
   xlab = "", ylab = "", col = back.col)
mtext(side = 3, plot.label, cex = cex.axis, line = 2)
for ( j in 1:dim(SimuData)[1] )
   lines( rep (tmp2$MaxMin[j], 2),
      c(tmp2$Repr.quant2[j],
      tmp2$Repr.quant4[j]),
      col = back.col )
lines(newdata$MaxMin, newdata$fit, lwd = lwd  )
lines(newdata$MaxMin, newdata$se1, lty = 2, lwd = lwd*.75)
lines(newdata$MaxMin, newdata$se2, lty = 2, lwd = lwd*.75)

{ if (plotLabel == TRUE)
  { mtext(side = 2, expression("Reproductive rate ("*italic(F["age=4"])*")"),
      line = -0, cex = cex.axis, outer = T)
    mtext(side = 1, Xlab, line = 0.1, cex = cex.axis, outer = T)
    if (formatC(summary(mod)$s.table[4],format = "f",digits = 2) !=  "0.00")
     { mtext( side = 3, adj = .5, cex = cex.axis*.8, line = 0.1,
        as.expression( substitute( edf[GAM] == Value  * ", " ~
           italic(P[GAM])*"-value" == Value1 * ", " ~ italic(R[adj])^2 == Value2,
           list( edf = "edf", GAM = "", Value = formatC(summary(mod)$edf,
           format = "f", digits = 3), Value1 = formatC(
           summary(mod)$s.table[4], format = "f", digits = 2),
           Value2 = formatC(summary(mod)$r.sq,format = "f", digits = 2) ) ) ) )
     }
    else
     { mtext( side = 3, adj = .5, cex = cex.axis*.8, line = 0.1,
        as.expression( substitute( edf[GAM] == Value  * ", " ~
           italic(P[GAM])*"-value" < Value1 * ", " ~ italic(R[adj])^2 == Value2,
           list( edf = "edf", GAM = "", Value = formatC(summary(mod)$edf,
           format = "f", digits = 2), Value1 = "0.01", Value2 =
           formatC(summary(mod)$r.sq,format = "f", digits = 2) ) ) ) )
     }
  }
  else
  { mtext(side = 2, expression("Reproduksjon ("*italic(F["age=4"])*")"),
      line = 0, cex = cex.axis, outer = T)
    mtext(side = 1, Xlab, line = 0.1, cex = cex.axis, outer = T)
  }
}
dev.copy(tiff, filename = "DATABASE/Reproduction(age_4).tiff", units="cm",
  width=14, height=14, res=600, compression = c("lzw"));dev.off()


   ### SURVIVAL: YOUNGEST- AND ADULT-CLASS ###

dev.new(width=14/2.54, height=14/2.54);par(bty = "l", cex.axis = cex.axis,
    mar = c(4, 4, 2.5, 0.35), oma = c(1, 1.8, 1, 0.5),
    layout( rbind( c(1,1) )))
tmp1 <- subset(SimuData, Class == "1")
tmp2 <- subset(SimuData, Class == "4")
mod <- gam((Surv.median) ~ s(MaxMin, bs = bs, k = k),                         # the GAM is fitted to data on adult survival only
   family = gaussian(link = "identity"),
   na.action = na.omit, data = tmp2)
plot(tmp2$Surv.median ~ tmp2$MaxMin,
   cex = cex.point, las = 1,
   ylim = c( min(c(tmp1$Surv.quant2, tmp2$Surv.quant2),
     na.rm = T), max(c(tmp1$Surv.quant4, tmp2$Surv.quant4), na.rm = T)),
   xlab = "", ylab = "")
mtext(side = 3, plot.label, cex = cex.axis, line = 2)
for ( j in 1:dim(SimuData)[1] )
   lines( rep (tmp2$MaxMin[j], 2),
      c(tmp2$Surv.quant2[j],
      tmp2$Surv.quant4[j]) )
newdata <- data.frame(MaxMin = seq(min(tmp2$MaxMin),
   max(tmp2$MaxMin), length.out = 100 ) )
newdata$fit <- ( predict(mod, newdata))
newdata$se1 <- ( predict(mod, newdata) +
   predict(mod, newdata, se.fit = T)$se.fit )
newdata$se2 <- ( predict(mod, newdata)  -
   predict(mod, newdata, se.fit = T)$se.fit )
lines(newdata$MaxMin, newdata$fit, lwd = lwd  )
lines(newdata$MaxMin, newdata$se1, lty = 2, lwd = lwd*.75)
lines(newdata$MaxMin, newdata$se2, lty = 2, lwd = lwd*.75)

{ if (plotLabel == TRUE)
  { mtext(side = 2, expression("Survival rate ("*italic(P)*")"),
      line = -0, cex = cex.axis, outer = T)
    mtext(side = 1, Xlab, line = 0.1, cex = cex.axis, outer = T)
    if (formatC(summary(mod)$s.table[4],format = "f",digits = 2) !=  "0.00")
     { mtext( side = 3, adj = .5, cex = cex.axis*.8, line = 0.1,
        as.expression( substitute( edf[GAM] == Value  * ", " ~
           italic(P[GAM])*"-value" == Value1 * ", " ~ italic(R[adj])^2 == Value2,
           list( edf = "edf", GAM = "", Value = formatC(summary(mod)$edf,
           format = "f", digits = 3), Value1 = formatC(
           summary(mod)$s.table[4], format = "f", digits = 2),
           Value2 = formatC(summary(mod)$r.sq,format = "f", digits = 2) ) ) ) )
     }
    else
     { mtext( side = 3, adj = .5, cex = cex.axis*.8, line = 0.1,
        as.expression( substitute( edf[GAM] == Value  * ", " ~
           italic(P[GAM])*"-value" < Value1 * ", " ~ italic(R[adj])^2 == Value2,
           list( edf = "edf", GAM = "", Value = formatC(summary(mod)$edf,
           format = "f", digits = 2), Value1 = "0.01", Value2 =
           formatC(summary(mod)$r.sq,format = "f", digits = 2) ) ) ) )
     }
  }
  else
  { mtext(side = 2, expression("Overlevelsesrate ("*italic(P)*")"),
      line = 0, cex = cex.axis, outer = T)
    mtext(side = 1, Xlab, line = 0.1, cex = cex.axis, outer = T)
  }
}
points(tmp1$Surv.median ~ tmp1$MaxMin, col = col[1],                          # adds median survival for the youngest age class to the plot
  cex = cex.point, pch = pch[2] )
for ( j in 1:dim(SimuData)[1] )
   lines( rep (tmp1$MaxMin[j], 2),
      c(tmp1$Surv.quant2[j],
      tmp1$Surv.quant4[j]), col  =col[1] )
dev.copy(tiff, filename = "DATABASE/Survival.tiff", units="cm", width=14,
  height=14, res=600, compression = c("lzw"));dev.off()


   ### POPULATION GROWTH RATES (LAMBDA) ###

dev.new(width=14/2.54, height=14/2.54);par(bty = "l", cex.axis = cex.axis,
    mar = c(4, 4, 2.5, 0.35), oma = c(1, 1.5, 1, 0.5),
    layout( rbind( c(1,1) )))

mod <- gam((Lambda.sim) ~ s(MaxMin, bs = bs, k = k),
   family = gaussian(link = "identity"),
   na.action = na.omit, data = SimuDataPop)
newdata <- data.frame(MaxMin = seq(min(SimuDataPop$MaxMin),
   max(SimuDataPop$MaxMin), length.out = 100 ) )
newdata$fit <- ( predict(mod, newdata))
newdata$se1 <- ( predict(mod, newdata) +
   predict(mod, newdata, se.fit = T)$se.fit )
newdata$se2 <- ( predict(mod, newdata)  -
   predict(mod, newdata, se.fit = T)$se.fit )
plot(SimuDataPop$Lambda.sim ~ SimuDataPop$MaxMin,
   col = back.col, cex = cex.point, ,
   las = 0, ylim = c( min(c(limLam[1], SimuDataPop$Lambda.simLCL, newdata$se2), na.rm = T),
   max(c(limLam[2], SimuDataPop$Lambda.simUCL, newdata$se1), na.rm = T)),xlab = "", ylab = "")
points(SimuDataPop$Lambda.Tuljapurk ~ SimuDataPop$MaxMin,
   cex = cex.point*.5, pch = 16, col = "dark grey")
mtext(side = 3, plot.label, cex = cex.axis, line = 2)
for ( j in 1:dim(SimuDataPop)[1] )
   lines( rep (SimuDataPop$MaxMin[j], 2),
      c(SimuDataPop$Lambda.simUCL[j],SimuDataPop$Lambda.simLCL[j]),
      col = back.col )
points(SimuDataPop$Lambda.Tuljapurk ~ SimuDataPop$MaxMin,                     # add the estimates using Tulpaurkar's approx. to the plot
   cex = cex.point*.5, pch = 16, col = "grey")
lines(newdata$MaxMin, newdata$fit, lwd = lwd )
lines(newdata$MaxMin, newdata$se1, lty = 2, lwd = lwd*.75)
lines(newdata$MaxMin, newdata$se2, lty = 2, lwd = lwd*.75)
{ if(length(newdata$fit[newdata$fit<=0])==0)
    { tmp <- 10 }
  else
    { tmp <- max(newdata$fit[newdata$fit<=0]) }
}
{ if (abs(tmp) <= 0.01)
    { newdata$Fit <- ifelse(newdata$fit == tmp, 1, 0)
      Newdata <- subset(newdata, Fit == 1)                                    # defines where lambda goes from being positive to being negative
      lines(x = rep(Newdata[,1],2), y = c(-100,tmp), col = "dark red",
        lty = 2)
      Tmp <- formatC(Newdata[,1],format = "f",digits = 3)
      text(Newdata[,1], y=tmp+.015, adj = 0.4, Tmp, col = "dark red",
        cex = cex.point)
      sink("DATABASE/LambdaGAM.txt")
      print("When lambda first becomes negative")
      print(Newdata);sink()
    }
}
{ if (plotLabel == TRUE)
  { mtext(side = 2, expression("Growth, "*italic(lambda)~"="~
      log[e]*"("*italic(N[t+1])*") - "*log[e]*"("*italic(N[t])*")"),
      line = -.7, cex = cex.axis, outer = T)
    mtext(side = 1, Xlab, line = 0.1, cex = cex.axis, outer = T)
    if (formatC(summary(mod)$s.table[4],format = "f",digits = 2) !=  "0.00")
     { mtext( side = 3, adj = .5, cex = cex.axis*.8, line = 0.1,
        as.expression( substitute( edf[GAM] == Value  * ", " ~
           italic(P[GAM])*"-value" == Value1 * ", " ~ italic(R[adj])^2 == Value2,
           list( edf = "edf", GAM = "", Value = formatC(summary(mod)$edf,
           format = "f", digits = 3), Value1 = formatC(
           summary(mod)$s.table[4], format = "f", digits = 2),
           Value2 = formatC(summary(mod)$r.sq,format = "f", digits = 2) ) ) ) )
     }
    else
     { mtext( side = 3, adj = .5, cex = cex.axis*.8, line = 0.1,
        as.expression( substitute( edf[GAM] == Value  * ", " ~
           italic(P[GAM])*"-value" < Value1 * ", " ~ italic(R[adj])^2 == Value2,
           list( edf = "edf", GAM = "", Value = formatC(summary(mod)$edf,
           format = "f", digits = 2), Value1 = "0.01", Value2 =
           formatC(summary(mod)$r.sq,format = "f", digits = 2) ) ) ) )
     }
  }
  else
  { mtext(side = 2, expression("Vekst, "*italic(lambda)~"="~
      log[e]*"("*italic(N[t+1])*") - "*log[e]*"("*italic(N[t])*")"),
      line = -.7, cex = cex.axis, outer = T)
    mtext(side = 1, Xlab, line = 0.1, cex = cex.axis, outer = T)
  }
}
dev.copy(tiff, filename = "DATABASE/lambda.tiff", units="cm", width=14,
  height=14, res=600, compression = c("lzw"));dev.off()


   ### GENERATION TIME (AVERAGE MATRIX) ###

dev.new(width=14/2.54, height=14/2.54);par(bty = "l", cex.axis = cex.axis,
    mar = c(4, 4, 2.5, 0.35), oma = c(1, 1.5, 1, 0.5),
    layout( rbind( c(1,1) )))

tmp <- subset(SimuDataPop, genTimeA.mean >= 1)
{ if (dim(tmp)[1] > 1)
    { mod <- gam(genTimeA.mean ~ s(MaxMin, bs = bs, k = k),
        family = gaussian(link = "identity"),
        na.action = na.omit, data = tmp)
      newdata <- data.frame(MaxMin = seq(min(tmp$MaxMin),
        max(tmp$MaxMin), length.out = 100 ) )
     newdata$fit <- ( predict(mod, newdata))
     newdata$se1 <- ( predict(mod, newdata) +
       predict(mod, newdata, se.fit = T)$se.fit )
     newdata$se2 <- ( predict(mod, newdata)  -
      predict(mod, newdata, se.fit = T)$se.fit )
    plot(SimuDataPop$genTimeA.mean ~ SimuDataPop$MaxMin,
      col = back.col, cex = cex.point,
      las = 0, ylim = c( min(c(SimuDataPop$genTimeA.mean, newdata$se2)),
                 max(c(SimuDataPop$genTimeA.mean, newdata$se1))),
      xlab = "",ylab = "")
    lines(newdata$MaxMin, newdata$fit, lwd = lwd )
    lines(newdata$MaxMin, newdata$se1, lty = 2, lwd = lwd*.75)
    lines(newdata$MaxMin, newdata$se2, lty = 2, lwd = lwd*.75)
    }
  else
    {
    plot(SimuDataPop$genTimeA.mean ~ SimuDataPop$MaxMin,
      col = back.col, cex = cex.point,
      las = 0, xlab = "", ylab = "")
    }
}
mtext(side = 3, plot.label, cex = cex.axis, line = 2)
{ if (plotLabel == TRUE)
  { mtext(side = 2, expression("Generation time (years)"),
      line = -.7, cex = cex.axis, outer = T)
    mtext(side = 1, Xlab, line = 0.1, cex = cex.axis, outer = T)
    { if (dim(tmp)[1] > 1)
        {  if (formatC(summary(mod)$s.table[4],format = "f",digits = 2) !=
               "0.00")
             { mtext( side = 3, adj = .5, cex = cex.axis*.8, line = 0.1,
                as.expression( substitute( edf[GAM] == Value  * ", " ~
                italic(P[GAM])*"-value" == Value1 * ", " ~ italic(R[adj])^2 == Value2,
                list( edf = "edf", GAM = "", Value = formatC(summary(mod)$edf,
                format = "f", digits = 3), Value1 = formatC(
                summary(mod)$s.table[4], format = "f", digits = 2),
                Value2 = formatC(summary(mod)$r.sq,format = "f", digits = 2) ) ) ) )
             }
           else
             { mtext( side = 3, adj = .5, cex = cex.axis*.8, line = 0.1,
                as.expression( substitute( edf[GAM] == Value  * ", " ~
                italic(P[GAM])*"-value" < Value1 * ", " ~ italic(R[adj])^2 == Value2,
                list( edf = "edf", GAM = "", Value = formatC(summary(mod)$edf,
                format = "f", digits = 2), Value1 = "0.01", Value2 =
                formatC(summary(mod)$r.sq,format = "f", digits = 2) ) ) ) )
             }
         }
    }
  }
  else
  { mtext(side = 2, expression("Generasjonstid (r)"),
      line = -.7, cex = cex.axis, outer = T)
    mtext(side = 1, Xlab, line = 0.1, cex = cex.axis, outer = T)
  }
}
dev.copy(tiff, filename = "DATABASE/GenerationTime(A.mean).tiff",
  units="cm", width=14, height=14, res=600, compression = c("lzw"));dev.off()
