                                       ############################################################
                                      ####                                                      ####
                                      ####  VITAL RATES, TEMPORAL TRENDS (IMPUATIONS), AND      ####
                                      ####  MANIPULATION OF ENVIRONMENTAL CONDITIONS:           ####
                                      ####                                                      ####
                                      ####  Lesser black-backed gull (Larus fuscus) on Horsvr, ####
                                      ####  Northern Norway                                     ####
                                      ####                                                      ####
                                      ####     Brd-Jrgen Brdsen (bjb@nina.no) & Jan Ove      ####
                                      ####     Bustnes, 16.02.2022                              ####
                                      ####                                                      ####
                                       ############################################################





                                        ################################
                                        # CHANGING OPTIONS & LIBRARIES #
                                        ################################


# NOTES: For this script to function (i.e., for the required input files to load and to store the output in the correct directory), you must ensure that:
#       1) you keep the same structure (directories) as in the original .zip-file;
#       2) you define the current working directory of this R-session to be the same directory as the location of the script file (run 'getwd()' the check this, and use 'setwd(path to
#          this directory on your computer)' to fix it.


   ### INSTALLING PACKAGES ###

install.packages( c("AICcmodavg", "psych", "openxlsx", "popbio"), # getting the required packaged (from the CRAN sever in Bergen, Norway)
    repos = "http://cran.ii.uib.no/" )                            #   another server can be selected by changing repos; or by running: 'install.packages(c("openxlsx","AICcmodavg", ...))'
library("AICcmodavg")                                             # loads the package 'AICcmodavg: Model selection and multimodel inference based on (Q)AIC(c)'
library("psych")                                                  # loads the package 'psych: Procedures for Psychological, Psychometric, and Personality Research'
library("openxlsx")                                               # loads the package 'openxlsx: Read, Write and Edit xlsx Files'
library("popbio")                                                 # loads the package 'popbio: Construction and Analysis of Matrix Population Models'


wd <- getwd()                                                     # get current working directory
Tmp <- unlist(strsplit(wd,"/"))                                   # splits the current working directory into its sub-directories
Tmp <- Tmp[-length(Tmp)]                                          # removes that last one
Tmp <- paste(Tmp,collapse="/")                                    # puts the path together again (i.e. the same as moving to the parent directory from the current working directory)
source("Logit.R")                                                 # gets the logit-function (see below for details)







                                        #############################
                                        # DATA IMPORT - VITAL RATES #
                                        #############################


   ### APPARENT SURVIVAL ###

load(paste(Tmp,                                                   # loads data on apparent survival (assuming 2 age-classes; the script 'SurvivalAnalyses.R'
  "/STATISTICAL_ANALYSES/Survival/SurvivalAnalyses/",             #  in the 'STATISTICAL_ANALYSES\Survival' directory needs to be ran first)
  "SurvivalAnalysis(AgeClass2).RData",
  sep=""))
dataSurv <- Gull_Phi
names(dataSurv) <- c("ageClass", "year", "survMean",
  "survSe", "survLcl", "survUcl")                                 # re-names the variables so they are more intuitive: Ucl and Lcl represses upper and lower 95% confidence intervals
tmp <- subset(dataSurv, ageClass == "[2,-)")                      # takes a subset of the adults to create the ranks
tmp$survMean[tmp$year == "2013"] <- NA                            # the estimates for 2013 is so uncertain that they are removed from any further analyses
tmp$survLcl[tmp$year == "2013"] <- NA
tmp$survUcl[tmp$year == "2013"] <- NA
tmp$survSe[tmp$year == "2013"] <- NA
tmp$SurvRank <- rank(tmp$survMean)
tmp$SurvRank[tmp$year == "2013"] <- NA
tmp$SurvRank <- tmp$SurvRank - min(tmp$SurvRank,na.rm = T)        # re-scales the ranks so they go from zero
tmp <- data.frame(year = tmp$year, SurvRank = tmp$SurvRank)
dataSurv <- merge(dataSurv, tmp)
tmp <- subset(dataSurv, ageClass == "[2,-)")                      # inserts NAs for 2013 (Appendix S2:Table S6)
tmp <- subset(tmp, year == "2013")
tmp[,3:6] <- NA
dataSurv[row.names(tmp),] <- tmp


   ### FLEDGLINGS PER NEST/PAIR ###

dataRecru <-  read.xlsx(                                          # imports the 'FledglingsNest.xlsx' in the 'STATISTICAL_ANALYSES/Data/Reproduction' directory
    xlsxFile = paste(Tmp,"/STATISTICAL_ANALYSES/Data/",           #  see input-file for metadata
      "Reproduction/FledglingsNest.xlsx",
      sep=""),
    sheet = "dataRecru")
names(dataRecru) <- c("year", "recr")
dataRecru$year <- as.factor(dataRecru$year)
dataRecru$RecrRank <- rank(dataRecru$recr)
dataRecru$RecrRank <- dataRecru$RecrRank - min(dataRecru$RecrRank)


   ### DATA ON RECRUITMENT: ESTIMATED NEST PREDATION RATES, LAYING AND HATCHING CLUTCH SIZE ###

load(paste(Tmp,                                                   # loads the new data on laying and hatching clutch size(depends on output from the 'ReproPredat.R'
  "/STATISTICAL_ANALYSES/ReprodPredation/ReproPredat/",           #  script in the 'STATISTICAL_ANALYSES\ReproPredat' directory)
  "ClutchAdjust.RDATA",                                           #  see 'STATISTICAL_ANALYSES/ReprodPredation/ReproPredat/ClutchAdjust.xlsx' for metadata
   sep=""))
tmp1 <- DataAdjustEggPred[,-c(3,7:12)]
tmp1 <- tmp1[,c(1:2,5,3:4)]
names(tmp1) <- gsub(x = names(tmp1), pattern = "LOWESS",          # uses the LOESS-smoother for a few negative values for hatching clutch size (Appendix S2:Table S5)
  replacement ="")

tmp  <- subset(tmp1, type =="Start (Control)")
tmp <- tmp[,-1]
names(tmp) <- gsub(pattern = "Clutch", replacement =              # renames the variables: this is the starting clutch size (i.e., at laying)
  "ClutchStart", x = names(tmp))
dataRecru <- merge(dataRecru, tmp, by.x = "year", by.y = "year")
dataRecru$ClutchStartRank <- rank(dataRecru$ClutchStart.mean)
dataRecru$ClutchStartRank <- dataRecru$ClutchStartRank -          # data on ranked Clutch Size
  min(dataRecru$ClutchStartRank)

tmp <- subset(tmp1, type =="End (Predated)")
tmp <- tmp[,-1]
names(tmp) <- gsub(pattern = "Clutch", replacement =              # renames the variables: this is the ending clutch size (i.e., at hatching)
  "ClutchEnd", x = names(tmp))
dataRecru <- merge(dataRecru, tmp, by.x = "year", by.y = "year")
dataRecru$ClutchEndRank <- rank(dataRecru$ClutchEnd.mean)
dataRecru$ClutchEndRank <- dataRecru$ClutchEndRank -              # data on ranked clutch size
  min(dataRecru$ClutchEndRank)


   ### MERGING DATA ON APPARENT SURVIVAL AND REPRODUCTION ###

dataSurRec <- merge(dataSurv, dataRecru, by.x = "year", by.y =
  "year", all  = T)

dir.create("VitalRates", showWarnings = F)
setwd("VitalRates")







                                        ##########################################################
                                        # TEMPORAL TRENDS AND IMPUTING VALUES FOR ADULT SURVIVAL #
                                        ##########################################################

  ### DATA ORGANIZATION ###

tmp <- subset(dataSurRec, ageClass=="[2,-)")                      # subsets the data - only adults: '[2,-)'
minYear <- min(as.numeric(tmp$year))                              # minimum and maximum value for year
maxYear <- max(as.numeric(tmp$year))
tmp$year <- as.factor(as.numeric(tmp$year)+                       # creates a factor version of year (excluding possible missing years)
  (min(as.numeric(levels(tmp$year)))-1))


   ### DEFINING CANDIDATE MODELS ###

mod1 <- lm(survMean~as.numeric(year), tmp)
mod2 <- update(mod1, ~.+I(as.numeric(year)^2))
# note: candidate models
# i      year  year2
# mod1   X
# mod2   X     X


   ### SELECTING THE MOST PARSIMONIOUS MODEL ###

Cand.models <- list()                                            # makes a list of the candidate models (to be used in the 'aictab' function in 'AICcmodavg' package)
Modnames <- c()                                                  # makes a vector of the names of the candidate models (to be used in the 'aictab' function in 'AICcmodavg' package)
 for (j in 1:(length(ls(pattern = "mod"))-1))                    # loop to create a list of models and a vector of model names (to be used in the 'aictab' function
  { Cand.models[[j]] <- get(paste("mod",j, sep = ""))            #  in 'AICcmodavg' package)
    Modnames <- c(Modnames, paste("mod",j, sep = "") )
  }
AICdata <- aictab(cand.set = Cand.models, modnames =             # calculates delta AICc-values for the different candidate models
   Modnames, second.ord = T, sort = T)
AICdata                                                          # printing the output of the model selection assessment
tmp2 <- as.data.frame(subset(AICdata, Delta_AICc <= 1.5))        # selects the simplest model (i.e., the one with the fewest estimated parameters) with a diff. in AICc less than or
tmp2 <- as.character(tmp2$Modnames[tmp2$K == min(tmp2$K)][1])    #  equal to 1.5
Mod <- get(as.character(tmp2))                                   # selects a 'winning' model and uses that for inference


   ### MODEL DIAGNOSTICS (SELECTED MODEL) ###

dev.new();par(mfrow = c(2,2));plot(Mod)


   ### MODEL SUMMARY 'BIOLOGICAL' AND 'STATISTICAL' SIGNIFICANCE ###

anova(Mod)                                                       # the ANOVA table
summary(Mod)                                                     # model summary


   ### PLOTTING THE MODEL AND DATA ###

graphics.off()
par(cex.axis = 1.2, cex.lab = 1.7, cex.axis = 1.5,
  mar = c(4.5, 4.9, 3.1, 1), bty = "l")
plot(survMean-100~year, tmp,
  ylab = expression("Apparent adult survival ("*italic(Phi[a])*")"),
  xlab = "Time  (year)",
  ylim = c(min(dataSurRec$survLcl[
      dataSurRec$ageClass == "[2,-)"], na.rm = T),
    max(dataSurRec$survUcl[
      dataSurRec$ageClass == "[2,-)"], na.rm = T)))
points(survMean~as.numeric(year), tmp,
  pch = 16, cex = 2.5, col = colors()[c(131)])
for(i in 1:maxYear)
  { lines(x = c(rep(i,2)), y = c(tmp$survLcl[i], tmp$survUcl[i]),
     col = colors()[c(131)]) }

newdata <- data.frame( year = seq(minYear, maxYear,               # creates a data frame used for making predictions
   length.out = 100 ) )
newdata$fit <- predict(Mod, newdata)                              # extracts the predictions
newdata$se1 <- newdata$fit  +                                     # extracts the predictions + 1 SE
 predict(Mod, newdata, se.fit = T)$se.fit
newdata$se2 <- newdata$fit  -                                     # extracts the predictions - 1 SE
 predict(Mod, newdata, se.fit = T)$se.fit
lines(newdata$year, newdata$fit, lwd = 3)                         # plotting the predictions
lines(newdata$year, newdata$se1, lty = 2)                         # plotting the predictions - 1 SE
lines(newdata$year, newdata$se2, lty = 2)                         # plotting the predictions + 1 SE
Newdata <- data.frame(year = c(9))
Newdata$fit <- predict(Mod, Newdata)                              # extracts the predictions
points(Newdata$fit~Newdata$year, lwd = 3,
   pch = 1, cex = 2.5, col = colors()[c(136)])
a <- formatC(summary(Mod)$coef[1,1],format = "f", digits = 3)     # extracts the estimated intercept
a.se <- ifelse(
   round(summary(Mod)$coef[1,2],3) == 0,                          # extracts its precision
   "<0.001", formatC(summary(Mod)$coef[1,2],
   format = "f", digits = 3))
b <- formatC(summary(Mod)$coef[2,1],format = "f", digits = 3)     # extracts the estimated slope
b.se <- ifelse(
   round(summary(Mod)$coef[2,2],3) == 0,                          # extracts its precision
   "<0.001", formatC(summary(Mod)$coef[2,2],
   format = "f", digits = 3))
sig <- formatC(summary(Mod)$r.square,format = "f", digits = 3)    # extracts the coefficient of determination from the model
mtext(side = 3, adj = .5, cex = 1.3, line = 1.3,                  # adds information about the model to the plot
  as.expression( substitute(
   italic(Phi[a]) == Value * "(" *
   Valueb* ")" * Value1 * "(" * Value1b* ")"%*%T*
   " (" *italic(R^2)* " = " * Value2 * ")",
   list( Value = a, Valueb = a.se, Value1 = b, Value1b = b.se,
    Value2 = sig) ) ) )
dev.copy(tiff, filename = "AdultSurvival.tiff", units="cm",
  width=17.78, height=17.78, res=600, compression = c("lzw"))
dev.off()


   ### IMPUTING MISSING DATA ###

VitalAdult <- subset(dataSurRec, ageClass == "[2,-)")             # data on survival/recruitment for the adults
VitalAdult$survMean[VitalAdult$year == 2013] <- NA                # defines survival in 2013 as NA
VitalAdult$survLcl[is.na(VitalAdult$survMean==T)] <-              # imputes average survival estimate (incl. its 95% CIs) for 2013 with
Newdata$fit                                                       #   the predictions from the temporal trend model
VitalAdult$survUcl[is.na(VitalAdult$survMean==T)] <-
  Newdata$fit
VitalAdult$SurvRank <- rank(VitalAdult$survMean)
VitalAdult$survSe[is.na(VitalAdult$survMean==T)] <-
  NA
VitalAdult$survMean[is.na(VitalAdult$survMean==T)] <-
  Newdata$fit
VitalAdult$SurvRank <- rank(VitalAdult$survMean)
VitalAdult$SurvRank <- VitalAdult$SurvRank -
  min(VitalAdult$SurvRank,na.rm = T)                              # re-scales the ranks so they go from zero
tmp <- cbind.data.frame(rank = VitalAdult$SurvRank, estimate =
  VitalAdult$survMean)
tmp[order(tmp[,1]),c(1,2)]


   ### STORING OUTPUT ###

sink("AdultSurvival.txt")
print("Temporal trends in adult survival");print("");print("")
print("-----------------------------------------------")
print("     MODEL SELECTION                           ")
print("-----------------------------------------------")
print(aictab(cand.set = Cand.models, modnames =  Modnames,
  second.ord = T, sort = F), digits = 4);
print(paste("MODEL SELECTED =",as.character(tmp2)));
print("");print("")
print("-----------------------------------------------")
print("     MODEL SUMMARY                             ")
print("-----------------------------------------------")
print(summary(Mod));print("");print("")
print("ANOVA TABLE")
print(anova(Mod));print("");print("")
print("-----------------------------------------------")
print("     95% CI                                    ")
print("-----------------------------------------------")
print(confint(Mod));print("");print("")
sink()

rm(list = ls(pattern = "tmp"))
rm(list = ls(pattern = "od"));rm(AICdata)                         # removed redundant objects
rm(newdata, Newdata, i, a, a.se, b, b.se, sig)






                                        ############################################################
                                        # TEMPORAL TREND AND IMPUTING VALUES FOR JUVENILE SURVIVAL #
                                        ############################################################


 ### DATA ORGANIZATION ###

graphics.off()
tmp <- subset(dataSurRec, ageClass=="[0-1]")                      # subsets the data - only juveniles: '[0,1]'
tmp1 <- tmp[1,]
tmp1[,3:dim(tmp)[2]] <- NA                                        # creates a data frame that contains all years (also those with missing information about survival)
tmp1 <- data.frame(year = c("2012","2013", "2016"),
  rbind.data.frame(tmp1[,2:dim(tmp1)[2]],
                   tmp1[,2:dim(tmp1)[2]],
                   tmp1[,2:dim(tmp1)[2]]))
tmp <- rbind.data.frame(tmp,tmp1)
tmp$year <- as.character(tmp$year)
tmp <- tmp[order(as.numeric(tmp$year)),]
tmp$year <- as.factor(tmp$year)
minYear <- min(as.numeric(tmp$year))
maxYear <- max(as.numeric(tmp$year))


   ### DEFINING CANDIDATE MODELS ###

mod1 <- lm(survMean~as.numeric(year), tmp)
mod2 <- update(mod1, ~.+I(as.numeric(year)^2))


   ### SELECTING THE MOST PARSIMONIOUS MODEL ###

Cand.models <- list()
Modnames <- c()
 for (j in 1:(length(ls(pattern = "mod"))-1))
  { Cand.models[[j]] <- get(paste("mod",j, sep = ""))
    Modnames <- c(Modnames, paste("mod",j, sep = "") )
  }
AICdata <- aictab(cand.set = Cand.models, modnames =
   Modnames, second.ord = T, sort = T)
AICdata
tmp2 <- as.data.frame(subset(AICdata, Delta_AICc <= 1.5))
tmp2 <- as.character(tmp2$Modnames[tmp2$K == min(tmp2$K)][1])
Mod <- get(as.character(tmp2))


   ### MODEL DIAGNOSTICS (SELECTED MODEL) ###

dev.new();par(mfrow = c(2,2));plot(Mod)


   ### MODEL SUMMARY 'BIOLOGICAL' AND 'STATISTICAL' SIGNIFICANCE ###

anova(Mod)
summary(Mod)


   ### PLOTTING THE MODEL AND DATA ###

graphics.off()
par(cex.axis = 1.2, cex.lab = 1.7, cex.axis = 1.5,
  mar = c(4.5, 4.9, 3.1, 1), bty = "l")
plot(survMean-100~year, tmp,
  ylab = expression("Apparent juvenile survival ("*italic(Phi[j])*")"),
  xlab = "Time  (year)",
  ylim = c(min(dataSurRec$survLcl[
      dataSurRec$ageClass == "[0-1]"], na.rm = T),
    max(dataSurRec$survUcl[
      dataSurRec$ageClass == "[0-1]"], na.rm = T)))
points(survMean~as.numeric(year), tmp,
  pch = 16, cex = 2.5, col = colors()[c(131)])
for(i in 1:maxYear)
  { lines(x = c(rep(i,2)), y = c(tmp$survLcl[i], tmp$survUcl[i]),
     col = colors()[c(131)]) }

newdata <- data.frame( year = seq(minYear, maxYear,
   length.out = 100 ) )
newdata$fit <- predict(Mod, newdata)
newdata$se1 <- newdata$fit  +
 predict(Mod, newdata, se.fit = T)$se.fit
newdata$se2 <- newdata$fit  -
 predict(Mod, newdata, se.fit = T)$se.fit
lines(newdata$year, newdata$fit, lwd = 3)
lines(newdata$year, newdata$se1, lty = 2)
lines(newdata$year, newdata$se2, lty = 2)
Newdata <- data.frame(year =
  as.numeric(tmp$year[is.na(tmp$survMean)==T]))                   # the missing years are 2012-13 and 2016
Newdata$fit <- predict(Mod, Newdata)
points(Newdata$fit~
       Newdata$year, lwd = 3,
   pch = 1, cex = 2.5, col = colors()[c(136)])
Newdata$fit <- predict(Mod, Newdata)
points(Newdata$fit~Newdata$year, lwd = 3,
   pch = 1, cex = 2.5, col = colors()[c(136)])
a <- formatC(summary(Mod)$coef[1,1],format = "f", digits = 3)
a.se <- ifelse(
   round(summary(Mod)$coef[1,2],3) == 0,
   "<0.001", formatC(summary(Mod)$coef[1,2],
   format = "f", digits = 3))
b <- formatC(summary(Mod)$coef[2,1],format = "f", digits = 3)
b.se <- ifelse(
   round(summary(Mod)$coef[2,2],3) == 0,
   "<0.001", formatC(summary(Mod)$coef[2,2],
   format = "f", digits = 3))
sig <- formatC(summary(Mod)$r.square,format = "f", digits = 3)
mtext(side = 3, adj = .5, cex = 1.3, line = 1.3,
  as.expression( substitute(
   italic(Phi[a]) == Value * "(" *
   Valueb* ")" * Value1 * "(" * Value1b* ")"%*%T*
   " (" *italic(R^2)* " = " * Value2 * ")",
   list( Value = a, Valueb = a.se, Value1 = b, Value1b = b.se,
    Value2 = sig) ) ) )
dev.copy(tiff, filename = "JuvenileSurvival.tiff", units="cm",
  width=17.78, height=17.78, res=600, compression = c("lzw"))
dev.off()


   ### IMPUTING MISSING DATA ###

VitalOffsp <- tmp
VitalOffsp$recr[is.na(VitalOffsp$recr)] <- 0
VitalOffsp <- VitalOffsp[order(VitalOffsp$year),]
VitalOffsp$survLcl[is.na(VitalOffsp$survMean==T)] <-
  Newdata$fit
VitalOffsp$survUcl[is.na(VitalOffsp$survMean==T)] <-
  Newdata$fit
VitalOffsp$survSe[is.na(VitalOffsp$survMean==T)] <-  NA
VitalOffsp$survMean[is.na(VitalOffsp$survMean==T)] <-
  Newdata$fit
VitalOffsp$SurvRank <- VitalAdult$SurvRank


   ### STORING OUTPUT ###

sink("JuvenileSurvival.txt")
print("Temporal trends in juvenile survival");print("");print("")
print("-----------------------------------------------")
print("     MODEL SELECTION                           ")
print("-----------------------------------------------")
print(aictab(cand.set = Cand.models, modnames =  Modnames,
  second.ord = T, sort = F), digits = 4);
print(paste("MODEL SELECTED =",as.character(tmp2)));
print("");print("")
print("-----------------------------------------------")
print("     MODEL SUMMARY                             ")
print("-----------------------------------------------")
print(summary(Mod));print("");print("")
print("ANOVA TABLE")
print(anova(Mod));print("");print("")
print("-----------------------------------------------")
print("     95% CI                                    ")
print("-----------------------------------------------")
print(confint(Mod));print("");print("")
sink()

rm(list = ls(pattern = "tmp"))
rm(list = ls(pattern = "od"));rm(AICdata)
rm(newdata, Newdata, i, a, a.se, b, b.se, sig)






                                        ##################################
                                        # CORRELATIONS BETWEEN VARIABLES #
                                        ##################################

   ### CONTINUOUS VARIABLES ###

tmp <- cbind.data.frame(
  VitalAdult[,grep(x = names(VitalAdult),                         # gets data on year and adult apparent survival
    pattern = c("year|survMean"))],
  VitalOffsp[,grep(x = names(VitalOffsp),                         # gets data on year and offspring apparent survival
    pattern = c("survMean"))],
  VitalAdult[,grep(x = names(VitalAdult),                         # gets data on laying clutch size
    pattern = c("^ClutchStart.mean$"))],
  VitalAdult[,grep(x = names(VitalAdult),                         # gets data on hatching clutch size
    pattern = c("^ClutchEnd.mean$"))],
  VitalAdult[,grep(x = names(VitalAdult),                         # gets data on fledgelings
    pattern = c("^recr$"))])
names(tmp) <- c("Time", "SurvAdu", "SurvOff",                     # re-naming the variable to make the plot understandable
  "LayingClutch", "HatchingClutch", "Fledglings")
dev.new(width = 24/2.54, height = 16/2.54)
  par(mar = c(3,3.3,1.5,.5), bty = "l",  mfrow =c(3,4),           # adjusts the right 'border to fit the legends'
  oma = c(0,0,2,0))
pairs.panels(tmp, rug = T, cor = T,                               # show scatter plot of matrices, bivariate scatter plots, histograms, and Pearson correlation from the 'psych' package
  smooth = T, ci = T, stars = T, method = "pearson",
  hist.col = "#00AFBB", density = TRUE)
mtext(side = 3, "Correlations: continous variables",
  outer = T, line = .8)
dev.copy(tiff, filename = "CorrScatter_Continous.tiff",
  units="cm", width=24, height=16,res=700,
  compression = c("lzw"));dev.off()


   ### RANKED VARIABLES ###

tmp <- cbind.data.frame(
  VitalAdult[,grep(x = names(VitalAdult),                         # gets data on year and ranked adult apparent survival
    pattern = c("year|SurvRank"))],
  VitalAdult[,grep(x = names(VitalAdult),                         # gets data on ranked laying clutch size
    pattern = c("^ClutchStartRank$"))],
  VitalAdult[,grep(x = names(VitalAdult),                         # gets data on ranked hatching clutch size
    pattern = c("^ClutchEndRank$"))],
  VitalAdult[,grep(x = names(VitalAdult),                         # gets data on ranked fledgelings
    pattern = c("^RecrRank$"))])

names(tmp) <- c("Time", "SurvAdu", "LayingClutch",
   "HatchingClutch", "Fledglings")
dev.new(width = 24/2.54, height = 16/2.54)
  par(mar = c(3,3.3,1.5,.5), bty = "l",  mfrow =c(3,4),
  oma = c(0,0,2,0))
pairs.panels(tmp, rug = T, cor = T,
  smooth = T, ci = T, stars = T, method = "pearson",
  hist.col = "#00AFBB", density = TRUE)
mtext(side = 3, "Correlations: ranked variables",
  outer = T, line = .8)
dev.copy(tiff, filename = "CorrScatter_Ranked.tiff",
  units="cm", width=24, height=16,res=700,
  compression = c("lzw"));dev.off()





                                        ##########################################
                                        # TEMPORAL TREND FOR FLEDGLINGS PER NEST #
                                        ##########################################

 ### DATA ORGANIZATION ###

graphics.off()
tmp <- subset(dataSurRec, ageClass=="[2,-)")
tmp$year <- as.factor(as.numeric(tmp$year)+(min(as.numeric(levels(tmp$year)))-1))



   ### DEFINING CANDIDATE MODELS ###

mod1 <- lm(log(recr+.1)~as.numeric(year), tmp)
mod2 <- update(mod1, ~.+I(as.numeric(year)^2))


   ### SELECTING THE MOST PARSIMONIOUS MODEL ###

Cand.models <- list()
Modnames <- c()
 for (j in 1:(length(ls(pattern = "mod"))-1))
  { Cand.models[[j]] <- get(paste("mod",j, sep = ""))
    Modnames <- c(Modnames, paste("mod",j, sep = "") )
  }
AICdata <- aictab(cand.set = Cand.models, modnames =
   Modnames, second.ord = T, sort = T)
AICdata
tmp2 <- as.data.frame(subset(AICdata, Delta_AICc <= 1.5))
tmp2 <- as.character(tmp2$Modnames[tmp2$K == min(tmp2$K)][1])
Mod <- get(as.character(tmp2))


   ### MODEL DIAGNOSTICS (SELECTED MODEL) ###

dev.new();par(mfrow = c(2,2));plot(Mod)


   ### MODEL SUMMARY 'BIOLOGICAL' AND 'STATISTICAL' SIGNIFICANCE ###

anova(Mod)
summary(Mod)


   ### PLOTTING THE MODEL AND DATA ###

graphics.off()
par(cex.axis = 1.2, cex.lab = 1.7, cex.axis = 1.5,
  mar = c(4.5, 4.9, 3.1, 1), bty = "l")
plot(recr-100~year, tmp,
  ylab = expression("Reproduction ("*"fledglings nest"^-1*")"),
  xlab = "Time (year)",
  ylim = c(min(tmp$recr, na.rm = T),
           max(tmp$recr, na.rm = T)))
points(recr~as.numeric(year), tmp,
  pch = 16, cex = 2.5, col = colors()[c(131)])
newdata <- data.frame( year = seq(minYear, maxYear,
   length.out = 100 ) )
newdata$fit <- predict(Mod, newdata)
newdata$se1 <- newdata$fit  +
 predict(Mod, newdata, se.fit = T)$se.fit
newdata$se2 <- newdata$fit  -
 predict(Mod, newdata, se.fit = T)$se.fit
newdata$fit <- exp(newdata$fit)-.1
newdata$se1 <- exp(newdata$se1)-.1
newdata$se2 <- exp(newdata$se2)-.1
lines(newdata$year, newdata$fit, lwd = 3)
lines(newdata$year, newdata$se1, lty = 2)
lines(newdata$year, newdata$se2, lty = 2)
a <- formatC(summary(Mod)$coef[1,1],format = "f", digits = 2)
a.se <- ifelse(
   round(summary(Mod)$coef[1,2],3) == 0,
   "<0.001", formatC(summary(Mod)$coef[1,2],
   format = "f", digits = 2))
b <- formatC(summary(Mod)$coef[2,1],format = "f", digits = 2)
b.se <- ifelse(
   round(summary(Mod)$coef[2,2],3) == 0,
   "<0.001", formatC(summary(Mod)$coef[2,2],
   format = "f", digits = 2))
b1<- formatC(summary(Mod)$coef[3,1],format = "f", digits = 2)
b1.se <- ifelse(
   round(summary(Mod)$coef[3,2],3) == 0,
   "<0.001", formatC(summary(Mod)$coef[3,2],
   format = "f", digits = 2))
sig <- formatC(summary(Mod)$r.square,format = "f", digits = 2)
mtext(side = 3, adj = .3, cex = 1.1, line = 1.2,
  as.expression( substitute(
   log[e]*"(chicks+0.1)" == Value * "(" *
   Valueb* ")" * Value1 * "(" * Value1b* ")"%*%T*"+"
   * Value2 * "(" * Value2b* ")"%*%T^2*
   " (" *italic(R^2)* " = " * Value3 * ")",
   list( Value = a, Valueb = a.se, Value1 = b, Value1b = b.se,
    Value2 = b1, Value2b = b1.se,
    Value3 = sig) ) ) )
dev.copy(tiff, filename = "FledglingsPerNest.tiff", units="cm",
  width=17.78, height=17.78, res=600, compression = c("lzw"))
dev.off()


   ### STORING OUTPUT ###

sink("FledglingsPerNest.txt")
print("Temporal trends in number of fledglings per nest");print("");print("")
print("-----------------------------------------------")
print("     MODEL SELECTION                           ")
print("-----------------------------------------------")
print(aictab(cand.set = Cand.models, modnames =  Modnames,
  second.ord = T, sort = F), digits = 4);
print(paste("MODEL SELECTED =",as.character(tmp2)));
print("");print("")
print("-----------------------------------------------")
print("     MODEL SUMMARY                             ")
print("-----------------------------------------------")
print(summary(Mod));print("");print("")
print("ANOVA TABLE")
print(anova(Mod));print("");print("")
print("-----------------------------------------------")
print("     95% CI                                    ")
print("-----------------------------------------------")
print(confint(Mod));print("");print("")
sink()

rm(list = ls(pattern = "tmp"))
rm(list = ls(pattern = "od"));rm(AICdata)
rm(newdata, a, a.se, b, b.se, sig)







                                        ##################################################
                                        # TEMPORAL TRENDS FOR LAYING (START) CLUTCH SIZE #
                                        ##################################################

 ### DATA ORGANIZATION ###

graphics.off()
tmp <- subset(dataSurRec, ageClass == "[2,-)")
minYear <- min(as.numeric(tmp$year))
maxYear <- max(as.numeric(tmp$year))
tmp$year <- as.factor(as.numeric(tmp$year)+(min(as.numeric(levels(tmp$year)))-1))


   ### DEFINING CANDIDATE MODELS ###

mod1 <- lm(ClutchStart.mean~as.numeric(year), tmp)
mod2 <- update(mod1, ~.+I(as.numeric(year)^2))


   ### SELECTING THE MOST PARSIMONIOUS MODEL ###

Cand.models <- list()
Modnames <- c()
 for (j in 1:(length(ls(pattern = "mod"))-1))
  { Cand.models[[j]] <- get(paste("mod",j, sep = ""))
    Modnames <- c(Modnames, paste("mod",j, sep = "") )
  }
AICdata <- aictab(cand.set = Cand.models, modnames =
   Modnames, second.ord = T, sort = T)
AICdata
tmp2 <- as.data.frame(subset(AICdata, Delta_AICc <= 1.5))
tmp2 <- as.character(tmp2$Modnames[tmp2$K == min(tmp2$K)][1])
Mod <- get(as.character(tmp2))


   ### MODEL DIAGNOSTICS (SELECTED MODEL) ###

dev.new();par(mfrow = c(2,2));plot(Mod)


   ### MODEL SUMMARY 'BIOLOGICAL' AND 'STATISTICAL' SIGNIFICANCE ###

anova(Mod)
summary(Mod)


   ### PLOTTING THE MODEL AND DATA ###

graphics.off()
par(cex.axis = 1.2, cex.lab = 1.7, cex.axis = 1.5,
  mar = c(4.5, 4.9, 3.1, 1), bty = "l")
plot(ClutchStart.mean-100~year, tmp,
  ylab = expression("Laying clutch size ("*"eggs nest"^-1*")"),
  xlab = "Time (year)",
  ylim = c(min(tmp$ClutchStart.se2, na.rm = T),
           max(tmp$ClutchStart.se1, na.rm = T)))
for(i in 1:dim(tmp)[1])
  { lines(x = rep(as.numeric(tmp$year)[i],2), y =
     c(tmp$ClutchStart.se2[i], tmp$ClutchStart.se1[i]),
     col = colors()[c(131)], lwd = 0.7) }
points(ClutchStart.mean~as.numeric(year), tmp,
  pch = 16, cex = 2.5, col = colors()[c(131)])
newdata <- data.frame( year = seq(minYear, maxYear,
   length.out = 100 ) )
newdata$fit <- predict(Mod, newdata)
newdata$se1 <- newdata$fit  +
 predict(Mod, newdata, se.fit = T)$se.fit
newdata$se2 <- newdata$fit  -
 predict(Mod, newdata, se.fit = T)$se.fit
lines(newdata$year, newdata$fit, lwd = 3)
lines(newdata$year, newdata$se1, lty = 2)
lines(newdata$year, newdata$se2, lty = 2)
a <- formatC(summary(Mod)$coef[1,1],format = "f", digits = 2)
a.se <- ifelse(
   round(summary(Mod)$coef[1,2],3) == 0,
   "<0.001", formatC(summary(Mod)$coef[1,2],
   format = "f", digits = 2))
b <- formatC(summary(Mod)$coef[2,1],format = "f", digits = 2)
b.se <- ifelse(
   round(summary(Mod)$coef[2,2],3) == 0,
   "<0.001", formatC(summary(Mod)$coef[2,2],
   format = "f", digits = 2))
sig <- formatC(summary(Mod)$r.square,format = "f", digits = 2)
mtext(side = 3, adj = .5, cex = 1.3, line = 1.3,
  as.expression( substitute(
   "eggs" == Value * "(" *
   Valueb* ")" * Value1 * "(" * Value1b* ")"%*%T*
   " (" *italic(R^2)* " = " * Value2 * ")",
   list( Value = a, Valueb = a.se, Value1 = b, Value1b = b.se,
    Value2 = sig) ) ) )
dev.copy(tiff, filename = "LayingClutchSize(Start).tiff", units="cm",
  width=17.78, height=17.78, res=600, compression = c("lzw"));dev.off()


   ### STORING OUTPUT ###

sink("LayingClutchSize(Start).txt")
print("Temporal trends in laying (start) clutch size");print("");print("")
print("-----------------------------------------------")
print("     MODEL SELECTION                           ")
print("-----------------------------------------------")
print(aictab(cand.set = Cand.models, modnames =  Modnames,
  second.ord = T, sort = F), digits = 4);
print(paste("MODEL SELECTED =",as.character(tmp2)));
print("");print("")
print("-----------------------------------------------")
print("     MODEL SUMMARY                             ")
print("-----------------------------------------------")
print(summary(Mod));print("");print("")
print("ANOVA TABLE")
print(anova(Mod));print("");print("")
print("-----------------------------------------------")
print("     95% CI                                    ")
print("-----------------------------------------------")
print(confint(Mod));print("");print("")
sink()

rm(list = ls(pattern = "tmp"))
rm(list = ls(pattern = "od"));rm(AICdata)
rm(newdata, i, a, a.se, b, b.se, sig)








                                        ##################################################
                                        # TEMPORAL TRENDS FOR HATCHING (END) CLUTCH SIZE #
                                        ##################################################

 ### DATA ORGANIZATION ###

graphics.off()
tmp <- subset(dataSurRec, ageClass == "[2,-)")
minYear <- min(as.numeric(tmp$year))
maxYear <- max(as.numeric(tmp$year))
tmp$year <- as.factor(as.numeric(tmp$year)+(min(as.numeric(levels(tmp$year)))-1))


   ### DEFINING CANDITATE MODELS ###

mod1 <- lm(ClutchEnd.mean~as.numeric(year), tmp)
mod2 <- update(mod1, ~.+I(as.numeric(year)^2))


   ### SELECTING THE MOST PARIMONOUS MODEL ###

Cand.models <- list()
Modnames <- c()
 for (j in 1:(length(ls(pattern = "mod"))-1))
  { Cand.models[[j]] <- get(paste("mod",j, sep = ""))
    Modnames <- c(Modnames, paste("mod",j, sep = "") )
  }
AICdata <- aictab(cand.set = Cand.models, modnames =
   Modnames, second.ord = T, sort = T)
AICdata
tmp2 <- as.data.frame(subset(AICdata, Delta_AICc <= 1.5))
tmp2 <- as.character(tmp2$Modnames[tmp2$K == min(tmp2$K)][1])
Mod <- get(as.character(tmp2))


   ### MODEL DIAGNOSTICS (SELECTED MODEL) ###

dev.new();par(mfrow = c(2,2));plot(Mod)


   ### MODEL SUMMARY 'BIOLOGICAL' AND 'STATISTICAL' SIGNIFICANCE ###

anova(Mod)
summary(Mod)


   ### PLOTTING THE MODEL AND DATA ###

graphics.off()
par(cex.axis = 1.2, cex.lab = 1.7, cex.axis = 1.5,
  mar = c(4.5, 4.9, 3.1, 1), bty = "l")
plot(ClutchEnd.mean-100~year, tmp,
  ylab = expression("Clutch size at hatching ("*"eggs nest"^-1*")"),
  xlab = "Time (year)",
  ylim = c(min(tmp$ClutchEnd.mean, na.rm = T),
           max(tmp$ClutchEnd.mean, na.rm = T)))
for(i in 1:dim(tmp)[1])
  { lines(x = rep(as.numeric(tmp$year)[i],2), y =
     c(tmp$ClutchEnd.se2[i], tmp$ClutchEnd.se1[i]),
     col = colors()[c(131)], lwd = 0.7) }
points(ClutchEnd.mean~as.numeric(year), tmp,
  pch = 16, cex = 2.5, col = colors()[c(131)])
newdata <- data.frame( year = seq(minYear, maxYear,
   length.out = 100 ) )
newdata$fit <- predict(Mod, newdata)
newdata$se1 <- newdata$fit  +
 predict(Mod, newdata, se.fit = T)$se.fit
newdata$se2 <- newdata$fit  -
 predict(Mod, newdata, se.fit = T)$se.fit
lines(newdata$year, newdata$fit, lwd = 3)
lines(newdata$year, newdata$se1, lty = 2)
lines(newdata$year, newdata$se2, lty = 2)
a <- formatC(summary(Mod)$coef[1,1],format = "f", digits = 2)
a.se <- ifelse(
   round(summary(Mod)$coef[1,2],2) == 0,
   "<0.01", formatC(summary(Mod)$coef[1,2],
   format = "f", digits = 2))
b <- formatC(summary(Mod)$coef[2,1],format = "f", digits = 2)
b.se <- ifelse(
   round(summary(Mod)$coef[2,2],2) == 0,
   "<0.01", formatC(summary(Mod)$coef[2,2],
   format = "f", digits = 2))
b1<- formatC(summary(Mod)$coef[3,1],format = "f", digits = 2)
b1.se <- ifelse(
   round(summary(Mod)$coef[3,2],2) == 0,
   "<0.01", formatC(summary(Mod)$coef[3,2],
   format = "f", digits = 2))
sig <- formatC(summary(Mod)$r.square,format = "f", digits = 2)
mtext(side = 3, adj = .3, cex = 1.1, line = 1.2,
  as.expression( substitute(
   "eggs" == Value * "(" *
   Valueb* ")" * Value1 * "(" * Value1b* ")"%*%T*"+"
   * Value2 * "(" * Value2b* ")"%*%T^2*
   " (" *italic(R^2)* " = " * Value3 * ")",
   list( Value = a, Valueb = a.se, Value1 = b, Value1b = b.se,
    Value2 = b1, Value2b = b1.se,
    Value3 = sig) ) ) )
dev.copy(tiff, filename = "HachingClutchSize(End).tiff", units="cm",
  width=17.78, height=17.78, res=600, compression = c("lzw"));dev.off()


   ### STORING OUTPUT ###

sink("HachingClutchSize(End).txt")
print("Temporal trends in hatching (end) clutch size");print("");print("")
print("-----------------------------------------------")
print("     MODEL SELECTION                           ")
print("-----------------------------------------------")
print(aictab(cand.set = Cand.models, modnames =  Modnames,
  second.ord = T, sort = F), digits = 4);
print(paste("MODEL SELECTED =",as.character(tmp2)));
print("");print("")
print("-----------------------------------------------")
print("     MODEL SUMMARY                             ")
print("-----------------------------------------------")
print(summary(Mod));print("");print("")
print("ANOVA TABLE")
print(anova(Mod));print("");print("")
print("-----------------------------------------------")
print("     95% CI                                    ")
print("-----------------------------------------------")
print(confint(Mod));print("");print("")
sink()

rm(list = ls(pattern = "tmp"))
rm(list = ls(pattern = "od"));rm(AICdata)
rm(newdata, i, a, a.se, b, b.se, b1, b1.se, sig, j)





                                        ###################################################################
                                        # FUNCTION FOR ASSIGNING EACH YEAR A PROBABILITY OF BEING SELCTED #
                                        ###################################################################

# NOTE: This function forms the basis for manipulating environmental conditions by creating the Environmental Harshness Index (EHI) and the Environmental Goodness Index (EGI).

   ### CREATING THE FUNCTION ###

YearProb <- function(
  rank      = 0,                                                  # the rank of the year being selected (must start at zero and increase positively )
  MaxMin    = 1/length(levels(dataSurRec$year)),                  # the difference between minimum (i.e., '0+MaxMin') and maximum (i.e., '1-MaxMin') possible probability
  ProbShape = "equal")                                            # shape of the relationship

    { nYear <- length(levels(as.factor(rank)))                    # the number of years
      ProbYear <- rep(1/nYear, nYear)                             # each year has the same probability of occurring
      tmp <- ProbYear[1]-MaxMin                                   # check if negative probabilities occur

      { if (tmp < 0)
          { print("Error-negative prob. not allowed") }

        else
          {
            if (ProbShape == "equal")                             # all years has the same chance of being selected
              { ProbYear <- ProbYear }
            else if (ProbShape == "increase")                     # the highest ranked years has an increasing probability of being selected
              { ProbYear <- rep(1/nYear, nYear)                   # the probability of a given year given that all years has the same chance of being selected
                aPr <- ProbYear[1]-MaxMin                         # the intercept for the model (i.e., probability of selecting the lowest ranked year)
                bPr <- ( (ProbYear[1]+MaxMin) - aPr ) /           # the slope is calculated as the difference in probability of selecting the  lowest and highest ranked year
                 ( max(rank) - min(rank) )                        # divided by the number of steps for the ranking
                ProbYear <- aPr + (rank*bPr)
              }
            else if (ProbShape == "decrease")                     # the highest ranked years has a decreasing probability of being selected
              { ProbYear <- rep(1/nYear, nYear)                   # the probability of a given year given that all years has the same chance of being selected
                aPr <- ProbYear[1]+MaxMin                         # the intercept for the model (i.e., probability of selecting the lowest ranked year)
                bPr <- ( (ProbYear[1]-MaxMin) - aPr ) /           # the slope is calculated as the difference in probability of selecting the  lowest and highest ranked year
                 ( max(rank) - min(rank) )                        # divided by the number of steps for the ranking
                ProbYear <- aPr + (rank*bPr)
              }
          }
      }
    }


  ### CREATING THE DATA FOR PLOTTING ###

tmp <- subset(VitalAdult, ageClass == "[2,-)")
tmp$survLcl[tmp$year == "2013"] <- NA
tmp$survUcl[tmp$year == "2013"] <- NA

tmp$Eq <- YearProb(rank = tmp$SurvRank )
tmp$In <-  YearProb(rank = tmp$SurvRank, ProbShape = "increase")
tmp$De <-  YearProb(rank = tmp$SurvRank, ProbShape = "decrease")


   ### PLOTTING EQUAL PROBABILITIES: STATUS QUO FOR THE ENVIRONMENT ###

dev.new();par(cex.axis = 1.2, cex.lab = 1.5,
  mar = c(4.5, 4.5, 2., 5), new = F, col.axis = "black")
tmp1 <- tapply(tmp$Eq,
  (as.numeric(tmp$year)+as.numeric(levels(tmp$year)[1])-1),
  mean,na.rm = T)
barplot(tmp1, xlab = "Time (year)", ylab = "",
  main = "Simulating status quo",
  col = colors()[c(131)],
  ylim = c(0,max(tmp$Eq+.1)))
mtext(side = 2, outer = T, expression(
  "Probability of occurrence ("*italic(P[year])*")"),
  cex = 1.5, line = -1.7, col = colors()[c(131)] )
par(new=T)
tmp1 <- barplot(tmp1, xlab = "", ylab = "",
  col = colors()[c(136)],
  ylim = c(min(tmp$survLcl,na.rm = T),max(tmp$survUcl,na.rm = T)),
  axes = FALSE);par(col.axis = colors()[c(136)])
axis(side = 4)
lines(y = tmp$survMean, x = tmp1, lwd = 3, col = colors()[c(136)])
lines(y = tmp$survLcl, x = tmp1, lwd = 2, lty = 2, col = colors()[c(136)])
lines(y = tmp$survUcl, x = tmp1, lwd = 2, lty = 2, col = colors()[c(136)])
points(tmp$survMean[tmp$year == "2013"] ~
   tmp1[c(9)], lwd = 3,
   pch = 1, cex = 2.5, col = colors()[c(136)])
mtext(side = 4, outer = T,  expression("Survival ("*
  italic(Phi)*")"%+-%" 95% CI"), col = colors()[c(136)],
  cex = 1.5, line = -1.7)
dev.copy(tiff, filename =
  "EqualProbability.tiff", units="cm",
  width=17.78, height=17.78, res=600, compression = c("lzw"));dev.off()

dev.new();par(cex.axis = 1.2, cex.lab = 1.5,
  mar = c(4.5, 4.5, 2., 5), new = F, col.axis = "black")
tmp1 <- tapply(tmp$Eq,
  (as.numeric(tmp$year)+as.numeric(levels(tmp$year)[1])-1),
  mean,na.rm = T)
barplot(tmp1, xlab = "Time (year)", ylab = "",
  main = "Simulating status quo",
  col = colors()[c(131)],
  ylim = c(0,max(tmp$Eq+.1)))
mtext(side = 2, outer = T, expression(
  "Probability of occurrence ("*italic(P[year])*")"),
  cex = 1.5, line = -1.7, col = colors()[c(131)] )
par(new=T)
tmp1 <- barplot(tmp1*0, xlab = "", ylab = "",
  col = colors()[c(136)],
  ylim = c(min(tmp$ClutchStart.se2,na.rm = T),max(tmp$ClutchStart.se1,na.rm = T)),
  axes = FALSE);par(col.axis = colors()[c(136)])
axis(side = 4)
lines(y = tmp$ClutchStart.mean, x = tmp1, lwd = 3, col = colors()[c(136)])
lines(y = tmp$ClutchStart.se1, x = tmp1, lwd = 2, lty = 2, col = colors()[c(136)])
lines(y = tmp$ClutchStart.se2, x = tmp1, lwd = 2, lty = 2, col = colors()[c(136)])
mtext(side = 4, outer = T,  expression("Laying clutch size ("*"eggs nest"^-1*") "%+-%" SE"),
  col = colors()[c(136)],
  cex = 1.5, line = -1.7)
dev.copy(tiff, filename =
  "EqualProbability(Repr).tiff", units="cm",
  width=17.78, height=17.78, res=600, compression = c("lzw"));dev.off()


   ### PLOTTING EGI ###

dev.new();par(cex.axis = 1.2, cex.lab = 1.5,
  mar = c(4.5, 4.5, 2., 5), new = F, col.axis = "black")
tmp1 <- tapply(tmp$In,
  (as.numeric(tmp$year)+as.numeric(levels(tmp$year)[1])-1),
  mean,na.rm = T)
barplot(tmp1, xlab = "Time (year)", ylab = "",
  main = "Simulating good conditions",
  col = colors()[c(131)],
  ylim = c(0,max(tmp$In+.1)))
mtext(side = 2, outer = T, expression(
  "Probability of occurrence ("*italic(P[year])*")"),
  cex = 1.5, line = -1.7, col = colors()[c(131)] )
par(new=T)
tmp1 <- barplot(tmp1, xlab = "", ylab = "",
  col = colors()[c(136)],
  ylim = c(min(tmp$survLcl,na.rm = T),max(tmp$survUcl,na.rm = T)),
  axes = FALSE);par(col.axis = colors()[c(136)])
axis(side = 4)
lines(y = tmp$survMean, x = tmp1, lwd = 3, col = colors()[c(136)])
lines(y = tmp$survLcl, x = tmp1, lwd = 2, lty = 2, col = colors()[c(136)])
lines(y = tmp$survUcl, x = tmp1, lwd = 2, lty = 2, col = colors()[c(136)])
points(tmp$survMean[tmp$year == "2013"] ~
   tmp1[c(9)], lwd = 3,
   pch = 1, cex = 2.5, col = colors()[c(136)])
mtext(side = 4, outer = T,  expression("Survival ("*
  italic(Phi)*")"%+-%" 95% CI"), col = colors()[c(136)],
  cex = 1.5, line = -1.7)
dev.copy(tiff, filename =
  "IncreasedProbability.tiff", units="cm",
  width=17.78, height=17.78, res=600, compression = c("lzw"));dev.off()

dev.new();par(cex.axis = 1.2, cex.lab = 1.5,
  mar = c(4.5, 4.5, 2., 5), new = F, col.axis = "black")
tmp1 <- tapply(tmp$In,
  (as.numeric(tmp$year)+as.numeric(levels(tmp$year)[1])-1),
  mean,na.rm = T)
barplot(tmp1, xlab = "Time (year)", ylab = "",
  main = "Simulating good conditions",
  col = colors()[c(131)],
  ylim = c(0,max(tmp$Eq+.1)))
mtext(side = 2, outer = T, expression(
  "Probability of occurrence ("*italic(P[year])*")"),
  cex = 1.5, line = -1.7, col = colors()[c(131)] )
par(new=T)
tmp1 <- barplot(tmp1*0, xlab = "", ylab = "",
  col = colors()[c(136)],
  ylim = c(min(tmp$ClutchStart.se2,na.rm = T),max(tmp$ClutchStart.se1,na.rm = T)),
  axes = FALSE);par(col.axis = colors()[c(136)])
axis(side = 4)
lines(y = tmp$ClutchStart.mean, x = tmp1, lwd = 3, col = colors()[c(136)])
lines(y = tmp$ClutchStart.se1, x = tmp1, lwd = 2, lty = 2, col = colors()[c(136)])
lines(y = tmp$ClutchStart.se2, x = tmp1, lwd = 2, lty = 2, col = colors()[c(136)])
mtext(side = 4, outer = T,  expression("Laying clutch size ("*"eggs nest"^-1*") "%+-%" SE"),
  col = colors()[c(136)],
  cex = 1.5, line = -1.7)
dev.copy(tiff, filename =
  "IncreasedProbability(Repr).tiff", units="cm",
  width=17.78, height=17.78, res=600, compression = c("lzw"));dev.off()


   ### PLOTTING EHI ###

dev.new();par(cex.axis = 1.2, cex.lab = 1.5,
  mar = c(4.5, 4.5, 2., 5), new = F, col.axis = "black")
tmp1 <- tapply(tmp$De,
  (as.numeric(tmp$year)+as.numeric(levels(tmp$year)[1])-1),
  mean,na.rm = T)
barplot(tmp1, xlab = "Time (year)", ylab = "",
  main = "Simulating poor conditions",
  col = colors()[c(131)],
  ylim = c(0,max(tmp$De+.1)))
mtext(side = 2, outer = T, expression(
  "Probability of occurrence ("*italic(P[year])*")"),
  cex = 1.5, line = -1.7, col = colors()[c(131)] )
par(new=T)
tmp1 <- barplot(tmp1, xlab = "", ylab = "",
  col = colors()[c(136)],
  ylim = c(min(tmp$survLcl,na.rm = T),max(tmp$survUcl,na.rm = T)),
  axes = FALSE);par(col.axis = colors()[c(136)])
axis(side = 4)
lines(y = tmp$survMean, x = tmp1, lwd = 3, col = colors()[c(136)])
lines(y = tmp$survLcl, x = tmp1, lwd = 2, lty = 2, col = colors()[c(136)])
lines(y = tmp$survUcl, x = tmp1, lwd = 2, lty = 2, col = colors()[c(136)])
mtext(side = 4, outer = T,  expression("Survival ("*
  italic(Phi)*")"%+-%" 95% CI"), col = colors()[c(136)],
  cex = 1.5, line = -1.7)
points(tmp$survMean[tmp$year == "2013"] ~
   tmp1[c(9)], lwd = 3,
   pch = 1, cex = 2.5, col = colors()[c(136)])
dev.copy(tiff, filename =
  "DecreasedProbability.tiff", units="cm",
  width=17.78, height=17.78, res=600, compression = c("lzw"));dev.off()


dev.new();par(cex.axis = 1.2, cex.lab = 1.5,
  mar = c(4.5, 4.5, 2., 5), new = F, col.axis = "black")
tmp1 <- tapply(tmp$De,
  (as.numeric(tmp$year)+as.numeric(levels(tmp$year)[1])-1),
  mean,na.rm = T)
barplot(tmp1, xlab = "Time (year)", ylab = "",
  main = "Simulating poor conditions",
  col = colors()[c(131)],
  ylim = c(0,max(tmp$De+.1)))
mtext(side = 2, outer = T, expression(
  "Probability of occurrence ("*italic(P[year])*")"),
  cex = 1.5, line = -1.7, col = colors()[c(131)] )
par(new=T)
tmp1 <- barplot(tmp1*0, xlab = "", ylab = "",
  col = colors()[c(136)],
  ylim = c(min(tmp$ClutchStart.se2,na.rm = T),max(tmp$ClutchStart.se1,na.rm = T)),
  axes = FALSE);par(col.axis = colors()[c(136)])
axis(side = 4)
lines(y = tmp$ClutchStart.mean, x = tmp1, lwd = 3, col = colors()[c(136)])
lines(y = tmp$ClutchStart.se1, x = tmp1, lwd = 2, lty = 2, col = colors()[c(136)])
lines(y = tmp$ClutchStart.se2, x = tmp1, lwd = 2, lty = 2, col = colors()[c(136)])
mtext(side = 4, outer = T,  expression("Laying clutch size ("*"eggs nest"^-1*") "%+-%" SE"),
  col = colors()[c(136)],
  cex = 1.5, line = -1.7)
dev.copy(tiff, filename =
  "DecreasedProbability(Repr).tiff", units="cm",
  width=17.78, height=17.78, res=600, compression = c("lzw"));dev.off()
rm(tmp, tmp1, dataSurRec, minYear, maxYear,
   DataAdjustEggPred, Metadata)

names(VitalAdult) <- gsub(pattern = "recr", replacement =         # renames the variables 'recr' into 'FledlingNest' which it really is
  "FledglengNest", x = names(VitalAdult))
names(VitalAdult) <- gsub(pattern = "Recr", replacement =
  "FledglengNest", x = names(VitalAdult))

names(VitalOffsp) <- gsub(pattern = "recr", replacement =
  "FledglengNest", x = names(VitalOffsp))
names(VitalOffsp) <- gsub(pattern = "Recr", replacement =
  "FledglengNest", x = names(VitalOffsp))





                                        ##########################################
                                        # MERGING THE DATA AND SAVING THE OUTPUT #
                                        ##########################################


attach(VitalAdult)
VitalAdult$EggPredProp <- VitalAdult$ClutchEnd.mean/              # calculates the proportion of the eggs being lost from laying to hatching
  VitalAdult$ClutchStart.mean
VitalAdult$EggPredProp.se1 <- VitalAdult$ClutchEnd.se1/           # calculates the proportion of the eggs being lost from laying to hatching based on -1SE for the estimates
  VitalAdult$ClutchStart.se1
VitalAdult$EggPredProp.se2 <- VitalAdult$ClutchEnd.se2/           # calculates the proportion of the eggs being lost from laying to hatching based on +1SE for the estimates
  VitalAdult$ClutchStart.se2

tmp <- grep(pattern = "surv", x = names(VitalOffsp))              # the only difference between 'VitalOffsp' and 'VitalAdult' is the survival estimates and ageClass
tmp1 <- VitalOffsp[,c(2,tmp)]
VitalOffsp <- VitalAdult
VitalOffsp[,c(2,tmp)] <- tmp1

VitalData <- rbind.data.frame(VitalOffsp, VitalAdult)             # merges the two data sets
row.names(VitalData) <- 1:dim(VitalData)[1]                       # creates chronological row names
row.names(VitalOffsp) <- 1:dim(VitalOffsp)[1]                     # creates chronological row names
row.names(VitalAdult) <- 1:dim(VitalAdult)[1]                     # creates chronological row names



   ### CALCULATING THE STABLE AGE STRUCTURE AND GENERATION TIME BASED ON THE AVERAGE FECUNDITY AND SURVIVAL (VITAL RATES) ###

# NOTE: This section estimates the stable age class based on the average survival and fecundity.

tmp <- data.frame(
    F = mean(VitalOffsp$ClutchStart.mean)*0.5*                    # average across all years: average laying clutch size * average proportion of eggs removed by predators *
        mean(VitalOffsp$EggPredProp,na.rm=T)*                     #   average juvenile survival * 0.5 (assuming 1:1 sex ratio)
        mean(VitalOffsp$survMean),
    P0   = mean(VitalOffsp$survMean, na.rm = T),
    P13  = mean(VitalAdult$survMean, na.rm = T) )
A.mean <- matrix(rep(0,4), 4, nrow = 4,  byrow = TRUE)
A.mean[1,4] <- tmp$F
A.mean[2,1] <- tmp$P0
A.mean[3,2] <- tmp$P13
A.mean[4,3] <- tmp$P13
A.mean[4,4] <- tmp$P13
p <- pop.projection(A = A.mean, n = rep(300/4,4), iterations =    # projecting population 200 years into the future using the matrix 'A.mean' and starting with 75 ind. per age class(depends on the popbio-package)
  200)
StableAge <- round(p$stable.stage,3)                              # the stable age distribution used to set-up the number of ind. in each age-class for the simulations (see also 'ExtinctionSensitivity.R' for details)
genTime <- generation.time(A.mean)                                # extracts generation time based on the average matrix (see also 'ExtinctionSensitivity.R' for details)
rm(A.mean, p, tmp)


   ### ESTIMATED MEAN, CV AND RANGE ###

tmp <-  subset(VitalAdult, year!="2013" &                         # data on adult survival (excluding 2013 and the last year)
  year!= levels(VitalAdult$year)[dim(VitalAdult)[1]])
descData <- data.frame(
   parameter = "SurvAdu",
   mean      = mean(tmp$survMean),                                # average
   min       = min(tmp$survMean),                                 # minimum value
   max       = max(tmp$survMean),                                 # maximum value
   sd        = sd(tmp$survMean),                                  # standard deviation
   CVnorm    = sd(tmp$survMean)/mean(tmp$survMean)*100,           # % CV probability-scale
   CVlogit   = abs( sd(Logit(tmp$survMean))/
     mean(Logit(tmp$survMean)))*100 )                             # % CV logit-scale

tmp <-  subset(VitalOffsp, year!="2012" & year!="2013" &
   year!="2016" & year!=
    levels(VitalAdult$year)[dim(VitalAdult)[1]])                  # data on offspring survival (excluding 2012-13, 2016 and the last year)
tmp1 <- data.frame(
   parameter = "SurvOff",
   mean      = mean(tmp$survMean),
   min       = min(tmp$survMean),
   max       = max(tmp$survMean),
   sd        = sd(tmp$survMean),
   CVnorm    = sd(tmp$survMean)/mean(tmp$survMean)*100,
   CVlogit   = abs( sd(Logit(tmp$survMean))/
     mean(Logit(tmp$survMean)))*100 )
descData <- rbind.data.frame(descData, tmp1)

tmp <-  subset(VitalOffsp)                                        # data on fledglings per nest
tmp1 <- data.frame(
   parameter = "Fledlings",
   mean      = mean(tmp$FledglengNest),
   min       = min(tmp$FledglengNest),
   max       = max(tmp$FledglengNest),
   sd        = sd(tmp$FledglengNest),
   CVnorm    = sd(tmp$FledglengNest)/mean(tmp$FledglengNest)*100,
   CVlogit   = NA )
descData <- rbind.data.frame(descData, tmp1)

tmp <-  subset(VitalOffsp)                                        # data on laying clutch size (Start) per nest
tmp1 <- data.frame(
   parameter = "ClutchStart.mean",
   mean      = mean(tmp$ClutchStart.mean),
   min       = min(tmp$ClutchStart.mean),
   max       = max(tmp$ClutchStart.mean),
   sd        = sd(tmp$ClutchStart.mean),
   CVnorm    = sd(tmp$ClutchStart.mean)/
    mean(tmp$ClutchStart.mean)*100,
   CVlogit   = NA )
descData <- rbind.data.frame(descData, tmp1)

tmp <-  subset(VitalOffsp)                                        # data on hatching clutch size (End) per nest
tmp1 <- data.frame(
   parameter = "ClutchEnd.mean",
   mean      = mean(tmp$ClutchEnd.mean),
   min       = min(tmp$ClutchEnd.mean),
   max       = max(tmp$ClutchEnd.mean),
   sd        = sd(tmp$ClutchEnd.mean),
   CVnorm    = sd(tmp$ClutchEnd.mean)/mean(tmp$ClutchEnd.mean)*100,
   CVlogit   = NA )
descData <- rbind.data.frame(descData, tmp1)

tmp <-  subset(VitalOffsp)                                        # data on proportional egg predation
tmp1 <- data.frame(
   parameter = "EggPredProp",
   mean      = mean(tmp$EggPredProp),
   min       = min(tmp$EggPredProp),
   max       = max(tmp$EggPredProp),
   sd        = sd(tmp$EggPredProp),
   CVnorm    = sd(tmp$EggPredProp)/mean(tmp$EggPredProp)*100,
   CVlogit   = abs( sd(Logit(tmp$EggPredProp))/
     mean(Logit(tmp$EggPredProp)))*100 )
descData <- rbind.data.frame(descData, tmp1)

tmp <-  subset(ClutchAdjust)                                      # data on empirical (observed) clutch size per nest
tmp1 <- data.frame(
   parameter = "ClutchEmpirical.mean",
   mean      = mean(tmp$Clutch.mean),
   min       = min(tmp$Clutch.mean),
   max       = max(tmp$Clutch.mean),
   sd        = sd(tmp$Clutch.mean),
   CVnorm    = sd(tmp$Clutch.mean)/mean(tmp$Clutch.mean)*100,
   CVlogit   = NA )
descData <- rbind.data.frame(descData, tmp1)                      # 'descData' is a data.frame with all these descriptive statistics included

tmp <- options()$width
options(width = 150)
sink("descData.txt")
cat("DESCRIPTIVE STATISTICS\n")
cat(paste("adult survival excluded 2013 and",                     # the subset used to estimate descriptive statistics for apparent adult survival
    levels(VitalAdult$year)[dim(VitalAdult)[1]]), "\n")
cat(paste("juv. survival excluded 2012-13, 2016 and",             # the subset used to estimate descriptive statistics for apparent juvenile survival
    levels(VitalAdult$year)[dim(VitalAdult)[1]]), "\n")
print(descData);sink()
options(width=tmp)

rm(tmp, wd, tmp1, ClutchAdjust, descData, Tmp, Gull_p,
  Gull_Phi, dataRecru, dataSurv, Logit)
save.image("VitalRates.RData")









                                        ########################
                                        # STORING SESSION INFO #
                                        ########################


sink("SessionInfo.txt")
print(sessionInfo(), locale = F)
sink()

