                                       ############################################################
                                      ####                                                      ####
                                      ####  LITTERATUR REVIEW:                                  ####
                                      ####                                                      ####
                                      ####  Lesser black-backed gull (Larus fuscus) on Horsvr, ####
                                      ####  Northern Norway                                     ####
                                      ####                                                      ####
                                      ####     Brd-Jrgen Brdsen (bjb@nina.no) & Jan Ove      ####
                                      ####     Bustnes, 22.02.2022                              ####
                                      ####                                                      ####
                                       ############################################################









                                        ################################
                                        # CHANGING OPTIONS & LIBRARIES #
                                        ################################


# NOTES: For this script to function (i.e., for the required input files to load and to store the output in the correct directory), you must ensure that:
#       1) you keep the same structure (directories) as in the original .zip-file;
#       2) you define the current working directory of this R-session to be the same directory as the location of the script file (run 'getwd()' the check this, and use 'setwd(path to
#          this directory on your computer)' to fix it.


   ### INSTALLING PACKAGES ###

install.packages( c("openxlsx", "betareg"),                       # getting the required packaged (from the CRAN sever in Bergen, Norway)
  repos = "http://cran.ii.uib.no/" )                              #   another server can be selected by changing repos; or manually by running: 'install.packages( c("openxlsx", "betareg"))'
library("openxlsx")                                               # loads the package 'openxlsx: Read, Write and Edit xlsx Files'
library("betareg")                                                # loads the package 'betareg: Beta Regression'


   ### DECRIPTIVE STATISTCS FUNCTION ###

n <- function(x) { sum(ifelse(is.na(x), 0, 1)) }                  # function to count the number of observations (excluding NAs)
se <- function(x) { sqrt(sd(x,na.rm=T)/n(x)) }                    # function to estimate Standard Errors SEs (excluding NAs)
DescStat <- function(
  data     = "name of data.frame",                                # function to estimate descriptive statistics and SE (excluding NAs): mean; median; Standard Deviation (SD); range (min;max)
  group    = "name of the grouping variable(s)",                  #   this functions needs the names of a given data.frame (in the R-workspace),
  response = "name of the response variable")                     #   the name of the grouping variables (at least one variable in the data.frame)
  { tmp <- get(data)                                              #   and the response variable (in the data.frame)
    tmp <- tmp[,grep(x=names(tmp),
      pattern = paste(c(group,response), collapse ="|"))]
    Tmp <- tmp[,grep(x=names(tmp),
      pattern = paste(group, collapse="|"))]
    { if (class(Tmp)=="data.frame")
        { Names <- names(Tmp)
          tmp$X <- apply(Tmp, 1, paste, collapse = "_" ) }
      else
        { Names <- names(tmp)[grep(x=names(tmp),pattern = group)]
          names(tmp)[grep(x=names(tmp),pattern = group)] <- "X"
        }
    }
    tmp$X <- as.factor(tmp$X)
    names(tmp)[grep(x=names(tmp),pattern = response)] <- "Y"
    mean <- as.vector(tapply(tmp$Y, tmp$X, mean, na.rm = T))
    median <- as.vector(tapply(tmp$Y, tmp$X, median, na.rm = T))
    sd <- as.vector(tapply(tmp$Y, tmp$X, sd, na.rm = T))
    se <- as.vector(tapply(tmp$Y, tmp$X, se))
    min <- as.vector(tapply(tmp$Y, tmp$X, min, na.rm = T))
    max <- as.vector(tapply(tmp$Y, tmp$X, max, na.rm = T))
    n <- as.vector(tapply(tmp$Y, tmp$X,n))
#    groups <-  levels(as.factor(tmp$X))
    { if (class(Tmp)=="data.frame")
        { groups <- strsplit(levels(tmp$X),"_" )
          groups <- data.frame(do.call(rbind, lapply(groups, rbind)))
          names(groups) <- names(Tmp)
        }
      else
        { groups <- data.frame(X=levels(tmp$X))
          names(groups) <- group
        }
    }
    out <- cbind.data.frame(groups,mean,median, sd, se, min, max, n)
    return(out)
  }









                                        ################################
                                        # DATA IMPORT AND MANIPULATION #
                                        ################################


   ### CREATES A PATH TO THE PARENT DIRECTORY ###

wd <- getwd()                                                     # get current working directory
Tmp <- unlist(strsplit(wd,"/"))                                   # splits the current working directory into its sub-directories
Tmp <- Tmp[-length(Tmp)]                                          # removes that last one
Tmp <- paste(Tmp,collapse="/")                                    # puts the path together again (i.e., the same as moving to the parent directory from the current working directory)


   ### DATA IMPORT (RAW DATA) ###

data <- read.xlsx(                                                # imports the data from the 'STATISTICAL_ANALYSES\Data\Literature' directory
  xlsxFile = paste(Tmp,
    "/Data/Literature/LiteratureData.xlsx",sep=""),
  sheet = 1, colNames = T)
data$Source2 <- ifelse(data$Source == "This study", "Horsvr",
  "Other studies")
data$Source2 <- as.factor(data$Source2)                           # creates a factor variable separating our study ('Horsvr'; baseline) from the other ('Other studies')
rm(Tmp)


   ### SUBSETS THE DATA FOR THE DIFFERENT ANALYSES ###

dataSurv <- subset(data, Type == "Adult survival")                # adult (apparent) survival
DataRecp <- subset(data, Type == "Recapture probability")         # adult recapture probability
DataRecr <- subset(data, Type == "Fledglings")                    # number of fledglings per nest/pair
DataPred <- subset(data, Type == "Egg predation")                 # percentage of eggs removed by predators
DataClut <- subset(data, Type == "Clutch size")                   # clutch size per nest/pair


   ### CREATES A DIRECTORY TO STORE OUTPUT ###

dir.create("LiteratureAnalyses", showWarnings = F)
setwd("LiteratureAnalyses")
rm(wd)









                                        ###########################
                                        # APPARENT ADULT SURVIVAL #
                                        ###########################


  ### DESCRIPTIVE STATISTICS ###

DescStat(group = "Source2", response = "Estimate",                # descriptive statistics
  data = "dataSurv")
tmp <- dataSurv
tmp$Estimate[tmp$Source2 == "Horsvr" & tmp$Year == 2019] <- NA   # excluding the last year (2019) for our study area, which we did in the main text, but not for the comparison across studies
DescStat(group = "Source2", response = "Estimate",
  data = "tmp")[1,]                                               # descriptive statistics for our study area as reported in the text: excluding the last year (2019)


   ### FITTING THE STATISTICAL MODEL ###

modSurv <- betareg(Estimate~ Source2, dataSurv)                   # using the Beta-regression models since the response is probabilities
summary(modSurv)                                                  # printing the model summary on screen
dev.new();par(mfrow = c(2,2)); plot(modSurv)                      # plotting the model diagnostics


   ### STORING THE OUTPUT ###

options(width = 300);sink("ApparentSuvival.txt")                  # stores the results as a .txt-file
cat("------------------------------\n")
cat("    DESCRIPTIVE STATISTICS    \n")
cat("------------------------------\n")
cat("\n");cat("\n");cat("   -->   All years   <--\n")
print(DescStat(group = "Source2", response = "Estimate",
  data = "dataSurv"));cat("\n");cat("\n")
cat("   -->   Excluding 2019    <--\n")
print(DescStat(group = "Source2", response = "Estimate",
  data = "tmp")[1,])
cat("\n");cat("\n");cat("\n")
cat("------------------------------\n")
cat("        MODEL SUMMARY         \n")
cat("------------------------------\n")
print(summary(modSurv))
sink();options(width = 80);rm(tmp)









                                        #################################
                                        # ADULT RE-SIGHTING PROBABILITY #
                                        #################################


  ### DESCRIPTIVE STATISTICS ###

DescStat(group = "Source2", response = "Estimate",
  data = "DataRecp")
tmp <- DataRecp
tmp$Estimate[tmp$Source2 == "Horsvr" & tmp$Year == 2019] <- NA   # excluding the last year (2019) for our study area, which we did in the main text, but not for the comparison across studies
DescStat(group = "Source2", response = "Estimate",
  data = "tmp")[1,]


   ### FITTING THE STATISTICAL MODEL ###

modRecp <- betareg(Estimate~ Source2, DataRecp)
summary(modRecp)
dev.new();par(mfrow = c(2,2)); plot(modRecp)


   ### STORING THE OUTPUT ###

options(width = 300);sink("ResightingProbability.txt")
cat("------------------------------\n")
cat("    DESCRIPTIVE STATISTICS    \n")
cat("------------------------------\n")
cat("\n");cat("\n");cat("   -->   All years   <--\n")
print(DescStat(group = "Source2", response = "Estimate",
  data = "DataRecp"));cat("\n");cat("\n")
cat("   -->   Excluding 2019    <--\n")
print(DescStat(group = "Source2", response = "Estimate",
  data = "tmp")[1,])
cat("\n");cat("\n");cat("\n")
cat("------------------------------\n")
cat("        MODEL SUMMARY         \n")
cat("------------------------------\n")
print(summary(modRecp))
sink();options(width = 80);rm(tmp)









                                        #################
                                        # EGG PREDATION #
                                        #################


  ### DESCRIPTIVE STATISTICS ###

DescStat(group = "Source2", response = "Estimate",
  data = "DataPred")
tmp <- DataPred
tmp$Estimate[tmp$Source2 == "Horsvr" & (tmp$Year == 2012 |
  tmp$Year == 2013 | tmp$Year == 2016)] <-  NA
DescStat(group = "Source2", response = "Estimate",
  data = "tmp")[1,]


   ### FITTING THE STATISTICAL MODEL ###

modPred <- betareg(I(Estimate/100)~ Source2, DataPred)            # makes the percentages (0-100) into proportions (0-1)
summary(modPred)
dev.new();par(mfrow = c(2,2)); plot(modPred)


   ### STORING THE OUTPUT ###

options(width = 300);sink("NestPredation.txt")
cat("------------------------------\n")
cat("    DESCRIPTIVE STATISTICS    \n")
cat("------------------------------\n")
cat("\n");cat("\n");cat("   -->   All years   <--\n")
print(DescStat(group = "Source2", response = "Estimate",
  data = "DataPred"));cat("\n");cat("\n")
cat("   -->   Excluding 2012-13 and 2016    <--\n")
print(DescStat(group = "Source2", response = "Estimate",
  data = "tmp")[1,])
cat("\n");cat("\n");cat("\n")
cat("------------------------------\n")
cat("        MODEL SUMMARY         \n")
cat("------------------------------\n")
print(summary(modPred))
sink();options(width = 80);rm(tmp)









                                        ###############
                                        # CLUTCH SIZE #
                                        ###############


  ### DESCRIPTIVE STATISTICS ###

DescStat(group = "Source2", response = "Estimate",
  data = "DataClut")
tmp <- DataClut
tmp$Estimate[tmp$Source2 == "Horsvr" & (tmp$Year == 2012 |
  tmp$Year == 2013 | tmp$Year == 2016)] <-  NA
DescStat(group = "Source2", response = "Estimate",
  data = "tmp")[1,]                                               # based on data for our study area excluding 2012-13 and 2016 when no chicks were marked


   ### FITTING THE STATISTICAL MODEL ###

modClut <- lm(Estimate ~ Source2, DataClut)
summary(modClut)
dev.new();par(mfrow = c(2,2)); plot(modClut)


   ### STORING THE OUTPUT ###

options(width = 300);sink("ClutchSize.txt")
cat("------------------------------\n")
cat("    DESCRIPTIVE STATISTICS    \n")
cat("------------------------------\n")
cat("\n");cat("\n");cat("   -->   All years   <--\n")
print(DescStat(group = "Source2", response = "Estimate",
  data = "DataClut"));cat("\n");cat("\n")
cat("   -->   Excluding 2012-13 and 2016    <--\n")
print(DescStat(group = "Source2", response = "Estimate",
  data = "tmp")[1,])
cat("\n");cat("\n");cat("\n")
cat("------------------------------\n")
cat("        MODEL SUMMARY         \n")
cat("------------------------------\n")
print(summary(modClut))
sink();options(width = 80);rm(tmp)









                                        ##############
                                        # FLEDGLINGS #
                                        ##############

  ### DESCRIPTIVE STATISTICS ###

DescStat(group = "Source2", response = "Estimate",
  data = "DataRecr")
tmp <- DataRecr
tmp$Estimate[tmp$Source2 == "Horsvr" & (tmp$Year == 2012 |
  tmp$Year == 2013 | tmp$Year == 2016)] <-  NA
DescStat(group = "Source2", response = "Estimate",
  data = "tmp")[1,]                                               # based on data for our study area excluding 2012-13 and 2016 when no chicks were marked


   ### FITTING THE STATISTICAL MODEL ###

modFled <- lm(log(Estimate+.1) ~ Source2, DataRecr)
summary(modFled)
dev.new();par(mfrow = c(2,2)); plot(modFled)


   ### STORING THE OUTPUT ###

options(width = 300);sink("Fledglings.txt")
cat("------------------------------\n")
cat("    DESCRIPTIVE STATISTICS    \n")
cat("------------------------------\n")
cat("\n");cat("\n");cat("   -->   All years   <--\n")
print(DescStat(group = "Source2", response = "Estimate",
  data = "DataRecr"));cat("\n");cat("\n")
cat("   -->   Excluding 2012-13 and 2016    <--\n")
print(DescStat(group = "Source2", response = "Estimate",
  data = "tmp")[1,])
cat("\n");cat("\n");cat("\n")
cat("------------------------------\n")
cat("        MODEL SUMMARY         \n")
cat("------------------------------\n")
print(summary(modFled))
sink();options(width = 80);rm(tmp)









                                        ############
                                        # PLOTTING #
                                        ############

graphics.off()


   ### APPARENT ADULT SURVIVAL AND RE-SIGHTING PROBABILITY ###

dev.new(height = 24/2.54, widht = 15/2.54)
par(bty = "l", cex.lab = 1.6, cex.axis = 1.6, mar = c(4.5, 5, 1,1),
    mfrow = c(2,1))

plot(Estimate ~ Source2, DataRecp,
   col = "blue",
   ylab = expression("Encounter probability ("*italic(p[a])*")"),
   xlab = "")
abline(h = median(DataRecp$Estimate), col = "red", lty = 2, lwd = 4)
plot(Estimate ~ Source2, dataSurv,
   col = "blue",
   ylab = expression("Adult survival ("*italic(Phi[a])*")"),
   xlab = "Source")
abline(h = median(dataSurv$Estimate,na.rm=T), col = "red", lty = 2, lwd = 4)
dev.copy(tiff, filename = "ApparentSurvvial.tiff", units="cm",
  width=15, height=24, res=600, compression = c("lzw"));dev.off()


   ### REPRODCUTION AND NEST PREATION  ###

dev.new(height = 246/2.54, widht = 15/2.54)
par(bty = "l", cex.lab = 1.6, cex.axis = 1.6, mar = c(4.5, 5, 1,1),
    mfrow = c(3,1))

plot(Estimate ~ Source2, DataClut,
   col = "blue",
   ylab = expression("Eggs nest"^-1),
   xlab = "")
abline(h = median(DataClut$Estimate), col = "red", lty = 2, lwd = 4)

plot(Estimate ~ Source2, DataRecr,
   col = "blue",
   ylab = expression("Fledglings nest"^-1),
   xlab = "")
abline(h = median(DataRecr$Estimate), col = "red", lty = 2, lwd = 4)

plot(Estimate ~ Source2, DataPred,
   col = "blue",
   ylab = expression("Egg predation (% lost)"),
   xlab = "Source")
abline(h = median(DataPred$Estimate), col = "red", lty = 2, lwd = 4)
dev.copy(tiff, filename = "ReproductionPredation.tiff", units="cm",
  width=15, height=24, res=600, compression = c("lzw"));dev.off()








                                        ########################
                                        # STORING SESSION INFO #
                                        ########################


sink("SessionInfo.txt")
print(sessionInfo(), locale = F)
sink()
